@@ -6,6 +6,7 @@ from pcs.cli.common import middleware
 from pcs.lib.commands import (
     acl,
     alert,
+    auth,
     booth,
     cib,
     cib_options,
@@ -144,6 +145,18 @@ def load_module(env, middleware_factory, name):  # noqa: PLR0911, PLR0912
             },
         )
 
+    if name == "auth":
+        return bind_all(
+            env,
+            middleware.build(),
+            {
+                "auth_hosts": auth.auth_hosts,
+                "auth_hosts_token_no_sync": auth.auth_hosts_token_no_sync,
+                "deauth_all_local_hosts": auth.deauth_all_local_hosts,
+                "deauth_hosts": auth.deauth_hosts,
+            },
+        )
+
     if name == "booth":
         bindings = {
             "config_destroy": booth.config_destroy,
@@ -155,6 +168,7 @@ def load_module(env, middleware_factory, name):  # noqa: PLR0911, PLR0912
             "create_in_cluster": booth.create_in_cluster,
             "disable_booth": booth.disable_booth,
             "enable_booth": booth.enable_booth,
+            "get_resource_ids_from_cluster": booth.get_resource_ids_from_cluster,
             "get_status": booth.get_status,
             "pull_config": booth.pull_config,
             "remove_from_cluster": booth.remove_from_cluster,
@@ -189,6 +203,8 @@ def load_module(env, middleware_factory, name):  # noqa: PLR0911, PLR0912
             env,
             middleware.build(middleware_factory.cib),
             {
+                "element_description_get": cib.element_description_get,
+                "element_description_set": cib.element_description_set,
                 "remove_elements": cib.remove_elements,
             },
         )
@@ -243,6 +259,7 @@ def load_module(env, middleware_factory, name):  # noqa: PLR0911, PLR0912
                 "node_add_guest": remote_node.node_add_guest,
                 "node_remove_remote": remote_node.node_remove_remote,
                 "node_remove_guest": remote_node.node_remove_guest,
+                "get_resource_ids": remote_node.get_resource_ids,
             },
         )
 
@@ -434,6 +451,7 @@ def load_module(env, middleware_factory, name):  # noqa: PLR0911, PLR0912
                 "move": resource.move,
                 "move_autoclean": resource.move_autoclean,
                 "restart": resource.restart,
+                "stop": resource.stop,
                 "unmanage": resource.unmanage,
                 "unmove_unban": resource.unmove_unban,
             },
