@@ -91,6 +91,8 @@ PCS_LONG_OPTIONS: Final = [
     "corosync_conf=",
     "booth-conf=",
     "booth-key=",
+    # do not stop resources in resource delete command
+    "no-stop",
     "no-watchdog-validation",
     # pcs cluster setup
     "no-cluster-uuid",
@@ -274,7 +276,7 @@ class ArgsByKeywords:
 
     def allow_repetition_only_for(self, keyword_set: StringCollection) -> None:
         """
-        Raise CmdLineInputError if a keyword has been repetead when not allowed
+        Raise CmdLineInputError if a keyword has been repeated when not allowed
 
         keyword_set -- repetition is allowed for these keywords
         """
@@ -286,7 +288,7 @@ class ArgsByKeywords:
 
     def ensure_unique_keywords(self) -> None:
         """
-        Raise CmdLineInputError if any keyword has been repetead
+        Raise CmdLineInputError if any keyword has been repeated
         """
         return self.allow_repetition_only_for(set())
 
@@ -551,6 +553,7 @@ class InputModifiers:
                 "--no-expire-check": "--no-expire-check" in options,
                 "--no-cluster-uuid": "--no-cluster-uuid" in options,
                 "--no-keys-sync": "--no-keys-sync" in options,
+                "--no-stop": "--no-stop" in options,
                 "--no-strict": "--no-strict" in options,
                 "--no-watchdog-validation": (
                     "--no-watchdog-validation" in options
