@@ -1,3 +1,6 @@
-from . import messages, output
+from . import (
+    messages,
+    output,
+)
 from .output import process_library_reports
 from .processor import ReportProcessorToConsole
