@@ -1,7 +1,5 @@
-from pcs import (
-    client,
-    usage,
-)
+from pcs import usage
+from pcs.cli import client
 from pcs.cli.common.routing import create_router
 
 client_cmd = create_router(
