@@ -5,6 +5,7 @@ from pcs import (
     resource,
     usage,
 )
+from pcs.cli.cib.element import command as cib_element_cmd
 from pcs.cli.common.routing import create_router
 from pcs.cli.resource.relations import show_resource_relations_cmd
 
@@ -18,6 +19,7 @@ resource_cmd = create_router(
         "help": lambda lib, argv, modifiers: print(usage.resource(argv)),
         "list": resource.resource_list_available,
         "describe": resource.resource_list_options,
+        "description": cib_element_cmd.description,
         "create": resource.resource_create,
         "move": resource.resource_move,
         "move-with-constraint": resource.resource_move_with_constraint,
@@ -28,8 +30,8 @@ resource_cmd = create_router(
         "agents": resource.resource_agents,
         "update": resource.update_cmd,
         "meta": resource_cli.meta,
-        "delete": resource.resource_remove_cmd,
-        "remove": resource.resource_remove_cmd,
+        "delete": resource_cli.remove,
+        "remove": resource_cli.remove,
         "status": resource.resource_status,
         "config": resource_cli.config,
         "group": create_router(
