@@ -4,7 +4,6 @@ FileTypeCode = NewType("FileTypeCode", str)
 
 BOOTH_CONFIG = FileTypeCode("BOOTH_CONFIG")
 BOOTH_KEY = FileTypeCode("BOOTH_KEY")
-CFGSYNC_CTL = FileTypeCode("CFGSYNC_CTL")
 CIB = FileTypeCode("CIB")
 COROSYNC_AUTHKEY = FileTypeCode("COROSYNC_AUTHKEY")
 COROSYNC_CONF = FileTypeCode("COROSYNC_CONF")
@@ -15,6 +14,7 @@ PACEMAKER_AUTHKEY = FileTypeCode("PACEMAKER_AUTHKEY")
 PCSD_ENVIRONMENT_CONFIG = FileTypeCode("PCSD_ENVIRONMENT_CONFIG")
 PCSD_SSL_CERT = FileTypeCode("PCSD_SSL_CERT")
 PCSD_SSL_KEY = FileTypeCode("PCSD_SSL_KEY")
+PCS_CFGSYNC_CTL = FileTypeCode("CFGSYNC_CTL")
 PCS_KNOWN_HOSTS = FileTypeCode("PCS_KNOWN_HOSTS")
 PCS_SETTINGS_CONF = FileTypeCode("PCS_SETTINGS_CONF")
 PCS_DR_CONFIG = FileTypeCode("PCS_DR_CONFIG")
