@@ -52,6 +52,7 @@ AGENT_SELF_VALIDATION_SKIPPED_UPDATED_RESOURCE_MISCONFIGURED = M(
     "AGENT_SELF_VALIDATION_SKIPPED_UPDATED_RESOURCE_MISCONFIGURED"
 )
 AGENT_SELF_VALIDATION_RESULT = M("AGENT_SELF_VALIDATION_RESULT")
+AUTHORIZATION_SUCCESSFUL = M("AUTHORIZATION_SUCCESSFUL")
 BAD_CLUSTER_STATE_FORMAT = M("BAD_CLUSTER_STATE_FORMAT")
 BAD_CLUSTER_STATE_DATA = M("BAD_CLUSTER_STATE_DATA")
 BAD_PCMK_API_RESPONSE_FORMAT = M("BAD_PCMK_API_RESPONSE_FORMAT")
@@ -95,12 +96,9 @@ CANNOT_BAN_RESOURCE_MULTIPLE_INSTANCES_NO_NODE_SPECIFIED = M(
 CANNOT_BAN_RESOURCE_STOPPED_NO_NODE_SPECIFIED = M(
     "CANNOT_BAN_RESOURCE_STOPPED_NO_NODE_SPECIFIED"
 )
-STOPPING_RESOURCES_BEFORE_DELETING = M("STOPPING_RESOURCES_BEFORE_DELETING")
-STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED = M(
-    "STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED"
-)
-CANNOT_STOP_RESOURCES_BEFORE_DELETING = M(
-    "CANNOT_STOP_RESOURCES_BEFORE_DELETING"
+STOPPING_RESOURCES = M("STOPPING_RESOURCES")
+STOPPED_RESOURCES_BEFORE_DELETE_CHECK_SKIPPED = M(
+    "STOPPED_RESOURCES_BEFORE_DELETE_CHECK_SKIPPED"
 )
 CANNOT_CREATE_DEFAULT_CLUSTER_PROPERTY_SET = M(
     "CANNOT_CREATE_DEFAULT_CLUSTER_PROPERTY_SET"
@@ -126,6 +124,7 @@ CANNOT_MOVE_RESOURCE_STOPPED_NO_NODE_SPECIFIED = M(
     "CANNOT_MOVE_RESOURCE_STOPPED_NO_NODE_SPECIFIED"
 )
 CANNOT_REMOVE_ALL_CLUSTER_NODES = M("CANNOT_REMOVE_ALL_CLUSTER_NODES")
+CANNOT_REMOVE_RESOURCES_NOT_STOPPED = M("CANNOT_REMOVE_RESOURCES_NOT_STOPPED")
 CANNOT_SET_ORDER_CONSTRAINTS_FOR_RESOURCES_IN_THE_SAME_GROUP = M(
     "CANNOT_SET_ORDER_CONSTRAINTS_FOR_RESOURCES_IN_THE_SAME_GROUP"
 )
@@ -212,6 +211,9 @@ COROSYNC_CONFIG_DISTRIBUTION_NODE_ERROR = M(
     "COROSYNC_CONFIG_DISTRIBUTION_NODE_ERROR"
 )
 COROSYNC_CONFIG_DISTRIBUTION_STARTED = M("COROSYNC_CONFIG_DISTRIBUTION_STARTED")
+COROSYNC_CONFIG_INVALID_PREVENTS_CLUSTER_JOIN = M(
+    "COROSYNC_CONFIG_INVALID_PREVENTS_CLUSTER_JOIN"
+)
 COROSYNC_CONFIG_MISSING_IDS_OF_NODES = M("COROSYNC_CONFIG_MISSING_IDS_OF_NODES")
 COROSYNC_CONFIG_MISSING_NAMES_OF_NODES = M(
     "COROSYNC_CONFIG_MISSING_NAMES_OF_NODES"
@@ -294,6 +296,7 @@ DLM_CLUSTER_RENAME_NEEDED = M("DLM_CLUSTER_RENAME_NEEDED")
 DR_CONFIG_ALREADY_EXIST = M("DR_CONFIG_ALREADY_EXIST")
 DR_CONFIG_DOES_NOT_EXIST = M("DR_CONFIG_DOES_NOT_EXIST")
 DUPLICATE_CONSTRAINTS_EXIST = M("DUPLICATE_CONSTRAINTS_EXIST")
+EMPTY_RESOURCE_SET = M("EMPTY_RESOURCE_SET")
 EMPTY_RESOURCE_SET_LIST = M("EMPTY_RESOURCE_SET_LIST")
 FENCE_HISTORY_COMMAND_ERROR = M("FENCE_HISTORY_COMMAND_ERROR")
 FENCE_HISTORY_NOT_SUPPORTED = M("FENCE_HISTORY_NOT_SUPPORTED")
@@ -315,7 +318,11 @@ HOST_ALREADY_IN_CLUSTER_CONFIG = M("HOST_ALREADY_IN_CLUSTER_CONFIG")
 HOST_ALREADY_IN_CLUSTER_SERVICES = M("HOST_ALREADY_IN_CLUSTER_SERVICES")
 ID_ALREADY_EXISTS = M("ID_ALREADY_EXISTS")
 ID_BELONGS_TO_UNEXPECTED_TYPE = M("ID_BELONGS_TO_UNEXPECTED_TYPE")
+ID_DOES_NOT_SUPPORT_ELEMENT_DESCRIPTIONS = M(
+    "ID_DOES_NOT_SUPPORT_ELEMENT_DESCRIPTIONS"
+)
 ID_NOT_FOUND = M("ID_NOT_FOUND")
+INCORRECT_CREDENTIALS = M("INCORRECT_CREDENTIALS")
 INVALID_CIB_CONTENT = M("INVALID_CIB_CONTENT")
 INVALID_ID_BAD_CHAR = M("INVALID_ID_BAD_CHAR")
 INVALID_ID_IS_EMPTY = M("INVALID_ID_IS_EMPTY")
@@ -329,10 +336,21 @@ INVALID_RESPONSE_FORMAT = M("INVALID_RESPONSE_FORMAT")
 INVALID_SCORE = M("INVALID_SCORE")
 INVALID_STONITH_AGENT_NAME = M("INVALID_STONITH_AGENT_NAME")
 INVALID_TIMEOUT_VALUE = M("INVALID_TIMEOUT_VALUE")
+META_ATTRS_NOT_VALIDATED_LOADING_ERROR = M(
+    "META_ATTRS_NOT_VALIDATED_LOADING_ERROR"
+)
+META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE = M(
+    "META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE"
+)
+META_ATTRS_UNKNOWN_TO_PCMK = M("META_ATTRS_UNKNOWN_TO_PCMK")
 MULTIPLE_RESULTS_FOUND = M("MULTIPLE_RESULTS_FOUND")
 MUTUALLY_EXCLUSIVE_OPTIONS = M("MUTUALLY_EXCLUSIVE_OPTIONS")
 NO_ACTION_NECESSARY = M("NO_ACTION_NECESSARY")
+NO_HOST_SPECIFIED = M("NO_HOST_SPECIFIED")
 NO_STONITH_MEANS_WOULD_BE_LEFT = M("NO_STONITH_MEANS_WOULD_BE_LEFT")
+NO_STONITH_MEANS_WOULD_BE_LEFT_DUE_TO_PROPERTIES = M(
+    "NO_STONITH_MEANS_WOULD_BE_LEFT_DUE_TO_PROPERTIES"
+)
 NODE_ADDRESSES_ALREADY_EXIST = M("NODE_ADDRESSES_ALREADY_EXIST")
 NODE_ADDRESSES_CANNOT_BE_EMPTY = M("NODE_ADDRESSES_CANNOT_BE_EMPTY")
 NODE_ADDRESSES_DUPLICATION = M("NODE_ADDRESSES_DUPLICATION")
@@ -365,6 +383,7 @@ NODE_NAMES_ALREADY_EXIST = M("NODE_NAMES_ALREADY_EXIST")
 NODE_NAMES_DUPLICATION = M("NODE_NAMES_DUPLICATION")
 NODE_NOT_FOUND = M("NODE_NOT_FOUND")
 NODE_REMOVE_IN_PACEMAKER_FAILED = M("NODE_REMOVE_IN_PACEMAKER_FAILED")
+NODE_REMOVE_IN_PACEMAKER_SKIPPED = M("NODE_REMOVE_IN_PACEMAKER_SKIPPED")
 NODE_REPORTS_UNEXPECTED_CLUSTER_NAME = M("NODE_REPORTS_UNEXPECTED_CLUSTER_NAME")
 NONE_HOST_FOUND = M("NONE_HOST_FOUND")
 NODE_USED_AS_TIE_BREAKER = M("NODE_USED_AS_TIE_BREAKER")
@@ -398,6 +417,13 @@ PARSE_ERROR_COROSYNC_CONF_UNEXPECTED_CLOSING_BRACE = M(
 )
 PARSE_ERROR_INVALID_FILE_STRUCTURE = M("PARSE_ERROR_INVALID_FILE_STRUCTURE")
 PARSE_ERROR_JSON_FILE = M("PARSE_ERROR_JSON_FILE")
+PCS_CFGSYNC_CONFIG_ACCEPTED = M("PCS_CFGSYNC_CONFIG_ACCEPTED")
+PCS_CFGSYNC_CONFIG_SAVE_ERROR = M("PCS_CFGSYNC_CONFIG_SAVE_ERROR")
+PCS_CFGSYNC_CONFIG_REJECTED = M("PCS_CFGSYNC_CONFIG_REJECTED")
+PCS_CFGSYNC_CONFIG_UNSUPPORTED = M("PCS_CFGSYNC_CONFIG_UNSUPPORTED")
+PCS_CFGSYNC_CONFLICT_REPEAT_ACTION = M("PCS_CFGSYNC_CONFLICT_REPEAT_ACTION")
+PCS_CFGSYNC_FETCHING_NEWEST_CONFIG = M("PCS_CFGSYNC_FETCHING_NEWEST_CONFIG")
+PCS_CFGSYNC_SENDING_CONFIGS_TO_NODES = M("PCS_CFGSYNC_SENDING_CONFIGS_TO_NODES")
 PCSD_VERSION_TOO_OLD = M("PCSD_VERSION_TOO_OLD")
 PCSD_SSL_CERT_AND_KEY_DISTRIBUTION_STARTED = M(
     "PCSD_SSL_CERT_AND_KEY_DISTRIBUTION_STARTED"
