@@ -77,3 +77,16 @@ RESOURCE_STONITH_COMMANDS_MISMATCH = _D("RESOURCE_STONITH_COMMANDS_MISMATCH")
 CANNOT_ADD_RULE_TO_CONSTRAINT_WRONG_TYPE = _D(
     "CANNOT_ADD_RULE_TO_CONSTRAINT_WRONG_TYPE"
 )
+
+# Removed after 0.12.0
+# Replaced by STOPPING_RESOURCES, CANNOT_REMOVE_RESOURCES_NOT_STOPPED, and
+# STOPPED_RESOURCES_BEFORE_DELETE_CHECK_SKIPPED.
+# The 'cib.remove_elements' library command no longer stops resources before
+# their deletion.
+STOPPING_RESOURCES_BEFORE_DELETING = _D("STOPPING_RESOURCES_BEFORE_DELETING")
+STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED = _D(
+    "STOPPING_RESOURCES_BEFORE_DELETING_SKIPPED"
+)
+CANNOT_STOP_RESOURCES_BEFORE_DELETING = _D(
+    "CANNOT_STOP_RESOURCES_BEFORE_DELETING"
+)
