@@ -6,7 +6,6 @@ from pcs.common.reports.dto import ReportItemContextDto
 _file_role_translation = {
     file_type_codes.BOOTH_CONFIG: "Booth configuration",
     file_type_codes.BOOTH_KEY: "Booth key",
-    file_type_codes.CFGSYNC_CTL: "Config synchronization configuration",
     file_type_codes.COROSYNC_AUTHKEY: "Corosync authkey",
     file_type_codes.COROSYNC_CONF: "Corosync configuration",
     file_type_codes.COROSYNC_QDEVICE_NSSDB: "QDevice certificate database",
@@ -17,6 +16,7 @@ _file_role_translation = {
     file_type_codes.PCSD_ENVIRONMENT_CONFIG: "pcsd configuration",
     file_type_codes.PCSD_SSL_CERT: "pcsd SSL certificate",
     file_type_codes.PCSD_SSL_KEY: "pcsd SSL key",
+    file_type_codes.PCS_CFGSYNC_CTL: "Config synchronization configuration",
     file_type_codes.PCS_KNOWN_HOSTS: "known-hosts",
     file_type_codes.PCS_SETTINGS_CONF: "pcs configuration",
 }
