@@ -1,15 +1,6 @@
 import uuid
-from dataclasses import (
-    astuple,
-    dataclass,
-)
-from typing import (
-    Generator,
-    MutableSet,
-    Optional,
-    TypeVar,
-    Union,
-)
+from dataclasses import astuple, dataclass
+from typing import Generator, MutableSet, Optional, TypeVar, Union
 
 from lxml import etree
 from lxml.etree import _Element
@@ -40,7 +31,11 @@ def get_unique_uuid(already_used: StringCollection) -> str:
 
 
 def format_os_error(e: OSError) -> str:
-    return f"{e.strerror}: '{e.filename}'" if e.filename else e.strerror
+    if e.filename:
+        return f"{e.strerror}: '{e.filename}'"
+    if e.strerror:
+        return e.strerror
+    return (f"{e.__class__.__name__} {e}").strip()
 
 
 def xml_fromstring(xml: str) -> _Element:
@@ -123,6 +118,12 @@ class Version:
     def __le__(self, other: "Version") -> bool:
         return self.as_full_tuple <= other.as_full_tuple
 
+    def __hash__(self) -> int:
+        # https://docs.astral.sh/ruff/rules/eq-without-hash/
+        # used self.as_full_tuple because __eq__ and __hash__ should be in sync,
+        # objects which compare equal must have the same hash value
+        return hash(self.as_full_tuple)
+
     # See, https://stackoverflow.com/questions/37557411/why-does-defining-the-argument-types-for-eq-throw-a-mypy-type-error
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Version):
