@@ -9,7 +9,6 @@ from pcs.lib.commands import (  # services,
     acl,
     alert,
     booth,
-    cfgsync,
     cib,
     cib_options,
     cluster,
@@ -17,6 +16,7 @@ from pcs.lib.commands import (  # services,
     constraint,
     fencing_topology,
     node,
+    pcs_cfgsync,
     qdevice,
     quorum,
     resource,
@@ -130,10 +130,6 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=booth.ticket_unstandby,
         required_permission=p.WRITE,
     ),
-    "cfgsync.get_configs": _Cmd(
-        cmd=cfgsync.get_configs,
-        required_permission=p.FULL,
-    ),
     "cluster.add_nodes": _Cmd(
         cmd=cluster.add_nodes,
         required_permission=p.FULL,
@@ -182,6 +178,14 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=cluster.wait_for_pcmk_idle,
         required_permission=p.READ,
     ),
+    "cib.element_description_get": _Cmd(
+        cmd=cib.element_description_get,
+        required_permission=p.READ,
+    ),
+    "cib.element_description_set": _Cmd(
+        cmd=cib.element_description_set,
+        required_permission=p.WRITE,
+    ),
     "cib.remove_elements": _Cmd(
         cmd=cib.remove_elements,
         required_permission=p.WRITE,
@@ -258,6 +262,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=node.standby_unstandby_list,
         required_permission=p.WRITE,
     ),
+    "pcs_cfgsync.get_configs": _Cmd(
+        cmd=pcs_cfgsync.get_configs,
+        required_permission=p.FULL,
+    ),
     "qdevice.client_net_destroy": _Cmd(
         cmd=qdevice.client_net_destroy,
         # Last step of adding qdevice into a cluster is distribution of
@@ -312,6 +320,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=resource_agent.get_agent_metadata,
         required_permission=p.READ,
     ),
+    "resource_agent.get_meta_attributes_metadata": _Cmd(
+        cmd=resource_agent.get_meta_attributes_metadata,
+        required_permission=p.READ,
+    ),
     # deprecated, API v1 compatibility
     "resource_agent.list_agents": _Cmd(
         cmd=resource_agent.list_agents,
@@ -392,6 +404,10 @@ COMMAND_MAP: Mapping[str, _Cmd] = {
         cmd=resource.restart,
         required_permission=p.WRITE,
     ),
+    "resource.stop": _Cmd(
+        cmd=resource.stop,
+        required_permission=p.WRITE,
+    ),
     "resource.unmanage": _Cmd(
         cmd=resource.unmanage,
         required_permission=p.WRITE,
