@@ -4,13 +4,16 @@ TAG_ACL_GROUP: Final = "acl_group"
 TAG_ACL_PERMISSION: Final = "acl_permission"
 TAG_ACL_ROLE: Final = "acl_role"
 TAG_ACL_TARGET: Final = "acl_target"
+TAG_ALERT: Final = "alert"
 TAG_CONSTRAINT_COLOCATION: Final = "rsc_colocation"
 TAG_CONSTRAINT_LOCATION: Final = "rsc_location"
 TAG_CONSTRAINT_ORDER: Final = "rsc_order"
 TAG_CONSTRAINT_TICKET: Final = "rsc_ticket"
 TAG_CRM_CONFIG: Final = "crm_config"
-TAG_OBJREF: Final = "obj_ref"
 TAG_FENCING_LEVEL: Final = "fencing-level"
+TAG_NODE: Final = "node"
+TAG_OBJREF: Final = "obj_ref"
+TAG_RECIPIENT: Final = "recipient"
 TAG_RESOURCE_BUNDLE: Final = "bundle"
 TAG_RESOURCE_CLONE: Final = "clone"
 TAG_RESOURCE_GROUP: Final = "group"
