@@ -1,11 +1,4 @@
-from typing import (
-    Iterable,
-    List,
-    Mapping,
-    Optional,
-    Set,
-    cast,
-)
+from typing import Iterable, Mapping, Optional, cast
 
 from lxml import etree
 from lxml.etree import _Element
@@ -14,10 +7,7 @@ from pcs.common import reports
 from pcs.common.pacemaker.resource.primitive import CibResourcePrimitiveDto
 from pcs.common.resource_agent.dto import ResourceAgentNameDto
 from pcs.lib import validate
-from pcs.lib.cib import (
-    nvpair_multi,
-    rule,
-)
+from pcs.lib.cib import nvpair_multi, rule
 from pcs.lib.cib.const import TAG_RESOURCE_PRIMITIVE as TAG
 from pcs.lib.cib.nvpair import (
     INSTANCE_ATTRIBUTES_TAG,
@@ -27,7 +17,9 @@ from pcs.lib.cib.nvpair import (
     get_value,
 )
 from pcs.lib.cib.resource.agent import get_default_operations
+from pcs.lib.cib.resource.meta import validate_meta_attributes
 from pcs.lib.cib.resource.operations import (
+    ResourceOperationFilteredIn,
     create_operations,
     op_element_to_dto,
 )
@@ -46,11 +38,19 @@ from pcs.lib.pacemaker.live import (
 )
 from pcs.lib.pacemaker.values import validate_id
 from pcs.lib.resource_agent import (
+    CrmResourceAgent,
+    ResourceAgentError,
     ResourceAgentFacade,
     ResourceAgentMetadata,
     ResourceAgentName,
+    get_crm_resource_metadata,
+    resource_agent_error_to_report_item,
+)
+from pcs.lib.resource_agent.const import (
+    PRIMITIVE_META,
+    STONITH_ACTION_REPLACED_BY,
+    STONITH_META,
 )
-from pcs.lib.resource_agent.const import STONITH_ACTION_REPLACED_BY
 
 
 def is_primitive(resource_el: _Element) -> bool:
@@ -108,7 +108,7 @@ def primitive_element_to_dto(
 
 def find_primitives_by_agent(
     resources_section: _Element, agent_name: ResourceAgentName
-) -> List[_Element]:
+) -> list[_Element]:
     """
     Returns list of primitive resource elements which are using same resource
     agent as specified by resource_agent_obj.
@@ -117,7 +117,7 @@ def find_primitives_by_agent(
     agent_name -- name of an agent resources of which should be returned
     """
     return cast(
-        List[_Element],
+        list[_Element],
         resources_section.xpath(
             ".//primitive[@class=$class_ and @type=$type_ {provider_part}]".format(
                 provider_part=(
@@ -148,7 +148,7 @@ def create(  # noqa: PLR0913
     # TODO remove this arg
     do_not_report_instance_attribute_server_exists: bool = False,
     enable_agent_self_validation: bool = False,
-):
+) -> _Element:
     # pylint: disable=too-many-arguments
     # pylint: disable=too-many-locals
     # pylint: disable=too-many-positional-arguments
@@ -235,6 +235,15 @@ def create(  # noqa: PLR0913
                     report_msg.option_type,
                     report_msg.allowed_patterns,
                 )
+    if any(meta_attributes.values()):
+        meta_attributes_type = (
+            STONITH_META
+            if resource_agent_facade.metadata.name.is_stonith
+            else PRIMITIVE_META
+        )
+        report_items += _validate_meta_attributes(
+            cmd_runner, meta_attributes_type, meta_attributes
+        )
     report_processor.report_list(report_items)
 
     if report_processor.has_errors:
@@ -253,32 +262,67 @@ def create(  # noqa: PLR0913
     )
 
 
+# TODO: implementation from the lib.command.resource should have been used. It
+# cannot be used now, because it would create a cyclic imports. The whole
+# resource create command must be refactored first to resolve it.
+def _validate_meta_attributes(
+    cmd_runner: CommandRunner,
+    meta_attributes_type: CrmResourceAgent,
+    meta_attributes: Mapping[str, str],
+) -> reports.ReportItemList:
+    report_list = []
+    try:
+        meta_metadata_params = get_crm_resource_metadata(
+            cmd_runner, meta_attributes_type
+        )
+        report_list.extend(
+            validate_meta_attributes(
+                [meta_attributes_type], meta_metadata_params, meta_attributes
+            )
+        )
+
+    except ResourceAgentError as e:
+        # we do not want to end with an error in case we were unable to
+        # load the metadata, to keep backwards compatibility
+        report_list.append(
+            resource_agent_error_to_report_item(
+                e, severity=reports.ReportItemSeverity.warning()
+            )
+        )
+        report_list.append(
+            reports.ReportItem.warning(
+                reports.messages.MetaAttrsNotValidatedLoadingError()
+            )
+        )
+    return report_list
+
+
 def append_new(  # noqa: PLR0913
-    resources_section,
-    id_provider,
-    resource_id,
-    standard,
-    provider,
-    agent_type,
+    resources_section: _Element,
+    id_provider: IdProvider,
+    resource_id: str,
+    standard: str,
+    provider: Optional[str],
+    agent_type: str,
     *,
-    instance_attributes=None,
-    meta_attributes=None,
-    operation_list=None,
-):
+    instance_attributes: Mapping[str, str],
+    meta_attributes: Mapping[str, str],
+    operation_list: Iterable[ResourceOperationFilteredIn],
+) -> _Element:
     # pylint:disable=too-many-arguments
     # pylint: disable=too-many-positional-arguments
     """
     Append a new primitive element to the resources_section.
 
-    etree.Element resources_section is place where new element will be appended
-    IdProvider id_provider -- elements' ids generator
-    string resource_id is id of new resource
-    string standard is a standard of resource agent (e.g. ocf)
-    string agent_type is a type of resource agent (e.g. IPaddr2)
-    string provider is a provider of resource agent (e.g. heartbeat)
-    dict instance_attributes will be nvpairs inside instance_attributes element
-    dict meta_attributes will be nvpairs inside meta_attributes element
-    list operation_list contains dicts representing operations
+    resources_section -- place where new element will be appended
+    id_provider -- elements' ids generator
+    resource_id -- id of new resource
+    standard -- a standard of resource agent (e.g. ocf)
+    provider -- a provider of resource agent (e.g. heartbeat)
+    agent_type -- a type of resource agent (e.g. IPaddr2)
+    instance_attributes -- will be nvpairs inside instance_attributes element
+    meta_attributes -- will be nvpairs inside meta_attributes element
+    operation_list -- contains dicts representing operations
         (e.g. [{"name": "monitor"}, {"name": "start"}])
     """
     attributes = {
@@ -300,7 +344,10 @@ def append_new(  # noqa: PLR0913
             primitive_element, meta_attributes, id_provider
         )
 
-    create_operations(
+    # TODO pcs.lib.cib.resource.operations module should be overhauled, because
+    # it mixes operations provided as an input with operations existing in CIB
+    # already. Because of this mix, it cannot be properly typed now.
+    create_operations(  # type: ignore
         primitive_element, id_provider, operation_list if operation_list else []
     )
 
@@ -332,7 +379,7 @@ def _validate_unique_instance_attributes(
         if not any(new_group_values_map.values()):
             continue
 
-        conflicting_resources: Set[str] = set()
+        conflicting_resources: set[str] = set()
         for primitive in same_agent_resources:
             if primitive.attrib["id"] == resource_id:
                 continue
@@ -489,7 +536,11 @@ def validate_resource_instance_attributes_update(
     report_items: reports.ReportItemList = []
     current_instance_attrs = get_nvset_as_dict(
         INSTANCE_ATTRIBUTES_TAG,
-        find_element_by_tag_and_id(TAG, resources_section, resource_id),
+        cast(
+            _Element,
+            # If the primitive element doesn't exist, a LibraryError is raised
+            find_element_by_tag_and_id(TAG, resources_section, resource_id),
+        ),
     )
 
     agent_name = resource_agent.metadata.name
