@@ -1,7 +1,4 @@
-from typing import (
-    Iterable,
-    Mapping,
-)
+from typing import Mapping
 
 from lxml.etree import _Element
 
@@ -9,10 +6,7 @@ from pcs.common import reports
 from pcs.common.services.interfaces import ServiceManagerInterface
 from pcs.common.tools import timeout_to_seconds
 from pcs.common.types import StringSequence
-from pcs.lib import (
-    sbd,
-    validate,
-)
+from pcs.lib import sbd, validate
 from pcs.lib.cib import nvpair_multi
 from pcs.lib.cib.tools import (
     IdProvider,
@@ -21,6 +15,7 @@ from pcs.lib.cib.tools import (
 )
 from pcs.lib.errors import LibraryError
 from pcs.lib.external import CommandRunner
+from pcs.lib.pacemaker.values import is_false
 from pcs.lib.resource_agent import ResourceAgentFacade
 
 READONLY_CLUSTER_PROPERTY_LIST = [
@@ -31,6 +26,10 @@ READONLY_CLUSTER_PROPERTY_LIST = [
     "last-lrm-refresh",
 ]
 _DEFAULT_CLUSTER_PROPERTY_SET_ID = "cib-bootstrap-options"
+_STONITH_WATCHDOG_TIMEOUT_PROPERTIES = [
+    "stonith-watchdog-timeout",
+    "fencing-watchdog-timeout",
+]
 
 
 def _validate_stonith_watchdog_timeout_property(
@@ -65,9 +64,30 @@ def _validate_stonith_watchdog_timeout_property(
     return report_list
 
 
+def _validate_not_disabling_fencing(
+    to_be_set_properties: Mapping[str, str],
+) -> reports.ReportItemList:
+    problematic_properties_setting = {
+        key: to_be_set_properties[key]
+        for key in ["stonith-enabled", "fencing-enabled"]
+        if key in to_be_set_properties and is_false(to_be_set_properties[key])
+    }
+
+    if problematic_properties_setting:
+        return [
+            reports.ReportItem.warning(
+                reports.messages.NoStonithMeansWouldBeLeftDueToProperties(
+                    problematic_properties_setting
+                ),
+            )
+        ]
+
+    return []
+
+
 def validate_set_cluster_properties(  # noqa: PLR0912
     runner: CommandRunner,
-    cluster_property_facade_list: Iterable[ResourceAgentFacade],
+    cluster_properties_facade: ResourceAgentFacade,
     properties_set_id: str,
     configured_properties: StringSequence,
     new_properties: Mapping[str, str],
@@ -77,7 +97,7 @@ def validate_set_cluster_properties(  # noqa: PLR0912
     """
     Validate that cluster properties and their values can be set.
 
-    cluster_property_facade_list -- facades for cluster properties metadata
+    cluster_properties_facade -- facade for cluster properties metadata
     properties_set_id -- id of the properties set to be updated
     configured_properties -- names of currently configured cluster properties
     new_properties -- dictionary of properties and their values to be set
@@ -88,8 +108,7 @@ def validate_set_cluster_properties(  # noqa: PLR0912
     # pylint: disable=too-many-locals
     possible_properties_dict = {
         parameter.name: parameter
-        for facade in cluster_property_facade_list
-        for parameter in facade.metadata.parameters
+        for parameter in cluster_properties_facade.metadata.parameters
         if parameter.name not in READONLY_CLUSTER_PROPERTY_LIST
     }
     severity = reports.get_severity(reports.codes.FORCE, force)
@@ -102,33 +121,37 @@ def validate_set_cluster_properties(  # noqa: PLR0912
         else:
             to_be_removed_properties.append(name)
 
-    report_list = validate.validate_set_unset_items(
-        to_be_set_properties.keys(),
-        to_be_removed_properties,
-        configured_properties,
-        reports.const.ADD_REMOVE_CONTAINER_TYPE_PROPERTY_SET,
-        reports.const.ADD_REMOVE_ITEM_TYPE_PROPERTY,
-        properties_set_id,
-        severity=severity,
-    )
+    report_list = []
 
     report_list.extend(
-        validate.NamesIn(
-            possible_properties_dict.keys(),
-            option_type="cluster property",
-            banned_name_list=READONLY_CLUSTER_PROPERTY_LIST,
+        validate.ValidatorAll(
+            cluster_properties_facade.get_validators_deprecated_parameters()
+        ).validate(new_properties)
+    )
+    report_list.extend(
+        validate.validate_set_unset_items(
+            to_be_set_properties.keys(),
+            to_be_removed_properties,
+            configured_properties,
+            reports.const.ADD_REMOVE_CONTAINER_TYPE_PROPERTY_SET,
+            reports.const.ADD_REMOVE_ITEM_TYPE_PROPERTY,
+            properties_set_id,
             severity=severity,
+        )
+    )
+    report_list.extend(
+        validate.ValidatorAll(
+            cluster_properties_facade.get_validators_allowed_parameters(
+                force=force,
+                banned_parameter_list=READONLY_CLUSTER_PROPERTY_LIST,
+            )
         ).validate(
             # Allow removing properties unknown to pacemaker while preventing
             # setting them. Prevent removing read-only properties.
             {
                 name: value
                 for name, value in new_properties.items()
-                if not (
-                    value == ""
-                    and name not in READONLY_CLUSTER_PROPERTY_LIST
-                    and name not in possible_properties_dict
-                )
+                if value != "" or name in READONLY_CLUSTER_PROPERTY_LIST
             }
         )
     )
@@ -142,7 +165,7 @@ def validate_set_cluster_properties(  # noqa: PLR0912
     validators: list[validate.ValidatorInterface] = []
     for property_name in to_be_set_properties:
         if property_name not in possible_properties_dict:
-            # unknow properties are reported by NamesIn validator
+            # unknown properties are reported by NamesIn validator
             continue
         property_metadata = possible_properties_dict[property_name]
         if property_metadata.type == "boolean":
@@ -191,7 +214,7 @@ def validate_set_cluster_properties(  # noqa: PLR0912
             )
         elif property_metadata.type in ["time", "timeout"]:
             # make stonith-watchdog-timeout value not forcable
-            if property_metadata.name == "stonith-watchdog-timeout":
+            if property_metadata.name in _STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
                 validators.append(
                     validate.ValueTimeInterval(
                         property_metadata.name,
@@ -217,17 +240,19 @@ def validate_set_cluster_properties(  # noqa: PLR0912
 
     # Only validate SWT if it is being set, or if it is being removed and it
     # actually exists in the current configuration.
-    if "stonith-watchdog-timeout" in new_properties and (
-        new_properties["stonith-watchdog-timeout"]
-        or "stonith-watchdog-timeout" in configured_properties
-    ):
-        report_list.extend(
-            _validate_stonith_watchdog_timeout_property(
-                service_manager,
-                new_properties["stonith-watchdog-timeout"],
-                force=force,
+    for prop_name in _STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+        if prop_name in new_properties and (
+            new_properties[prop_name] or prop_name in configured_properties
+        ):
+            report_list.extend(
+                _validate_stonith_watchdog_timeout_property(
+                    service_manager,
+                    new_properties[prop_name],
+                    force=force,
+                )
             )
-        )
+
+    report_list.extend(_validate_not_disabling_fencing(to_be_set_properties))
 
     return report_list
 
