@@ -196,7 +196,7 @@ def setup(  # noqa:  PLR0913, PLR0915
     nodes: Sequence[Mapping[str, Any]],
     transport_type: Optional[str] = None,
     transport_options: Optional[Mapping[str, str]] = None,
-    link_list: Optional[Sequence[Mapping[str, Any]]] = None,
+    link_list: Optional[Sequence[Mapping[str, str]]] = None,
     compression_options: Optional[Mapping[str, str]] = None,
     crypto_options: Optional[Mapping[str, str]] = None,
     totem_options: Optional[Mapping[str, str]] = None,
@@ -398,7 +398,7 @@ def setup(  # noqa:  PLR0913, PLR0915
                 )
             )
             # Local certificate and key cannot be used because the local node
-            # may not be a part of the new cluter at all.
+            # may not be a part of the new cluster at all.
             ssl_key_raw = ssl.generate_key()
             ssl_key = ssl.dump_key(ssl_key_raw)
             ssl_cert = ssl.dump_cert(
@@ -458,7 +458,7 @@ def setup_local(  # noqa: PLR0913
     nodes: Sequence[Mapping[str, Any]],
     transport_type: Optional[str],
     transport_options: Mapping[str, str],
-    link_list: Sequence[Mapping[str, Any]],
+    link_list: Sequence[Mapping[str, str]],
     compression_options: Mapping[str, str],
     crypto_options: Mapping[str, str],
     totem_options: Mapping[str, str],
@@ -583,7 +583,7 @@ def _validate_create_corosync_conf(  # noqa: PLR0913
     nodes: Sequence[Mapping[str, Any]],
     transport_type: str,
     transport_options: Mapping[str, str],
-    link_list: Sequence[Mapping[str, Any]],
+    link_list: Sequence[Mapping[str, str]],
     compression_options: Mapping[str, str],
     crypto_options: Mapping[str, str],
     totem_options: Mapping[str, str],
@@ -644,7 +644,7 @@ def _create_corosync_conf(  # noqa: PLR0913
     nodes: Sequence[Mapping[str, Any]],
     transport_type: str,
     transport_options: Mapping[str, str],
-    link_list: Sequence[Mapping[str, Any]],
+    link_list: Sequence[Mapping[str, str]],
     compression_options: Mapping[str, str],
     crypto_options: Mapping[str, str],
     totem_options: Mapping[str, str],
