@@ -693,7 +693,7 @@ def _get_link_options_validators_udp(
         validate.ValueIn("broadcast", ("0", "1")),
         validate.ValueIpAddress("mcastaddr"),
         validate.ValuePortNumber("mcastport"),
-        validate.ValueIntegerInRange("ttl", 0, 255),
+        validate.ValueInteger("ttl", 0, 255),
     ]
     if allow_empty_values:
         for val in validators:
@@ -834,21 +834,25 @@ def _get_link_options_validators_knet(
 ) -> list[validate.ValidatorInterface]:
     # This only returns validators checking single values. Add checks for
     # intervalues relationships as needed.
+
+    # default value used in knet 1.0. Might be configurable in knet 2.0
+    knet_thread_timer_res_ms = 200
+
     validators = [
-        validate.ValueIntegerInRange("link_priority", 0, 255),
+        validate.ValueInteger("link_priority", 0, 255),
         validate.ValuePortNumber("mcastport"),
-        validate.ValueNonnegativeInteger("ping_interval"),
+        validate.ValueInteger("ping_interval", knet_thread_timer_res_ms, None),
         validate.ValueNonnegativeInteger("ping_precision"),
-        validate.ValueNonnegativeInteger("ping_timeout"),
+        validate.ValueInteger("ping_timeout", knet_thread_timer_res_ms, None),
         validate.ValueNonnegativeInteger("pong_count"),
         validate.ValueIn("transport", ("sctp", "udp")),
+        # DEPRECATED in knet 1, to be removed in knet 2.0
+        validate.ValueDeprecated("transport", {"sctp": None}),
     ]
 
     if including_linknumber:
         validators.append(
-            validate.ValueIntegerInRange(
-                "linknumber", 0, constants.LINKS_KNET_MAX - 1
-            )
+            validate.ValueInteger("linknumber", 0, constants.LINKS_KNET_MAX - 1)
         )
         allowed_options = constants.LINK_OPTIONS_KNET_USER
     else:
@@ -2109,7 +2113,7 @@ def _get_qdevice_model_net_options_validators(
         validate.ValueNotEmpty("host", "a qdevice host address"),
     ]
     validators_optional_options = [
-        validate.ValueIntegerInRange(
+        validate.ValueInteger(
             "connect_timeout", 1000, 2 * 60 * 1000, severity=severity
         ),
         validate.ValueIn(
