@@ -3,6 +3,7 @@ from pcs.common.resource_agent import const
 from .types import (
     _FAKE_AGENT_STANDARD,
     CrmAttrAgent,
+    CrmResourceAgent,
     FakeAgentName,
     OcfVersion,
 )
@@ -14,6 +15,8 @@ SUPPORTED_OCF_VERSIONS = [OCF_1_0, OCF_1_1]
 FAKE_AGENT_STANDARD = _FAKE_AGENT_STANDARD
 CLUSTER_OPTIONS = CrmAttrAgent("cluster-options")
 PACEMAKER_FENCED = FakeAgentName("pacemaker-fenced")
+PRIMITIVE_META = CrmResourceAgent("primitive-meta")
+STONITH_META = CrmResourceAgent("stonith-meta")
 
 
 STONITH_ACTION_REPLACED_BY = ["pcmk_off_action", "pcmk_reboot_action"]
