@@ -52,7 +52,7 @@ from pcs.common.reports import (
     ReportItemList,
     ReportItemSeverity,
 )
-from pcs.common.str_tools import format_list
+from pcs.common.str_tools import format_list, format_optional
 from pcs.common.tools import timeout_to_seconds
 from pcs.common.types import (
     StringCollection,
@@ -506,6 +506,43 @@ class NamesIn(KeyValidator):
         return report_list
 
 
+class PcmkMetaAttributeNamesIn(KeyValidator):
+    """
+    Report warning META_ATTRS_UNKNOWN_TO_PCMK for option_dict keys not in
+    option_name_list
+    """
+
+    def __init__(
+        self,
+        option_name_list: Iterable[TypeOptionName],
+        # TODO: resolve cycle dependency and change to
+        # Iterable[CrmResourceAgent]
+        option_type_list: StringIterable,
+    ):
+        super().__init__(option_name_list)
+        self._option_type_list = option_type_list
+
+    def validate(self, option_dict: TypeOptionMap) -> ReportItemList:
+        unknown_meta = set(option_dict.keys()) - set(self._option_name_list)
+        report_list = []
+        if unknown_meta:
+            # Meta attributes are meant for storing values in arbitrary keys -
+            # users can put any keys into meta attributes. Some of those keys
+            # are recognized and processed by pacemaker. But we ALWAYS want to
+            # ALLOW ANY KEYS. So this must never be an error.
+            report_list.append(
+                ReportItem(
+                    severity=reports.ReportItemSeverity.warning(),
+                    message=reports.messages.MetaAttrsUnknownToPcmk(
+                        sorted(unknown_meta),
+                        sorted(self._option_name_list),
+                        sorted(self._option_type_list),
+                    ),
+                )
+            )
+        return report_list
+
+
 ### values validators
 
 
@@ -749,30 +786,19 @@ class ValueInteger(ValuePredicateBase):
     Report INVALID_OPTION_VALUE when the value is not an integer
     """
 
-    def _is_valid(self, value: TypeOptionValue) -> bool:
-        return is_integer(value, None, None)
-
-    def _get_allowed_values(self) -> Any:
-        return "an integer"
-
-
-class ValueIntegerInRange(ValuePredicateBase):
-    """
-    Report INVALID_OPTION_VALUE when the value is not an integer such that
-    at_least <= value <= at_most
-    """
-
     def __init__(
         self,
         option_name: TypeOptionName,
-        at_least: int,
-        at_most: int,
+        at_least: Optional[int] = None,
+        at_most: Optional[int] = None,
         option_name_for_report: Optional[str] = None,
         severity: Optional[ReportItemSeverity] = None,
     ):
         """
-        at_least -- minimal allowed value
-        at_most -- maximal allowed value
+        at_least -- minimal allowed value, do not check the lower bound when
+            set to None
+        at_most -- maximal allowed value, do not check the upper bound when set
+            to None
         severity -- severity of produced reports, defaults to error
         """
         super().__init__(
@@ -787,6 +813,12 @@ class ValueIntegerInRange(ValuePredicateBase):
         return is_integer(value, self._at_least, self._at_most)
 
     def _get_allowed_values(self) -> Any:
+        if self._at_least is None and self._at_most is None:
+            return "an integer"
+        if self._at_most is None:
+            return f"an integer greater than or equal to {self._at_least}"
+        if self._at_least is None:
+            return f"an integer smaller than or equal to {self._at_most}"
         return f"{self._at_least}..{self._at_most}"
 
 
@@ -846,6 +878,41 @@ class ValueNotEmpty(ValuePredicateBase):
         return self._value_desc_or_enum
 
 
+class ValueStringLength(ValuePredicateBase):
+    """
+    Report INVALID_OPTION_VALUE when the value is longer than max len
+    """
+
+    def __init__(
+        self,
+        option_name: TypeOptionName,
+        min_len: Optional[int] = None,
+        max_len: Optional[int] = None,
+        option_name_for_report: Optional[str] = None,
+    ):
+        super().__init__(
+            option_name, option_name_for_report=option_name_for_report
+        )
+        self._min_len = min_len
+        self._max_len = max_len
+        self._value_cannot_be_empty = (
+            self._min_len is not None and self._min_len > 0
+        )
+
+    def _is_valid(self, value: TypeOptionValue) -> bool:
+        return is_string_length(value, self._min_len, self._max_len)
+
+    def _get_allowed_values(self) -> Any:
+        return "a string{min_len}{max_len}".format(
+            min_len=format_optional(
+                self._min_len, template=" (min length: {})"
+            ),
+            max_len=format_optional(
+                self._max_len, template=" (max length: {})"
+            ),
+        )
+
+
 class ValuePcmkBoolean(ValuePredicateBase):
     """
     Report INVALID_OPTION_VALUE when the value is not a pacemaker boolean value
@@ -1061,6 +1128,23 @@ def is_empty_string(value: TypeOptionValue) -> bool:
     return isinstance(value, str) and not value
 
 
+def is_string_length(
+    value: TypeOptionValue, min_len: Optional[int], max_len: Optional[int]
+) -> bool:
+    """
+    Check if the specified value is string with specified length
+
+    value -- value to check
+    min_len -- minimal length
+    max_len -- maximal length
+    """
+    return (
+        isinstance(value, str)
+        and (min_len is None or len(value) >= min_len)
+        and (max_len is None or len(value) <= max_len)
+    )
+
+
 def is_float(
     value: Union[str, int, float],
 ) -> bool:
