@@ -4,24 +4,14 @@ import re
 import sys
 import textwrap
 from functools import partial
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Mapping,
-    Optional,
-)
+from typing import TYPE_CHECKING, Any, Callable, Mapping, Optional
 from xml.dom.minidom import parseString
 
 import pcs.lib.pacemaker.live as lib_pacemaker
 import pcs.lib.resource_agent as lib_ra
-from pcs import (
-    constraint,
-    utils,
-)
+from pcs import constraint, utils
 from pcs.cli.cluster_property.output import PropertyConfigurationFacade
 from pcs.cli.common.errors import CmdLineInputError
-from pcs.cli.common.output import smart_wrap_text
 from pcs.cli.common.parse_args import (
     FUTURE_OPTION,
     OUTPUT_FORMAT_VALUE_CMD,
@@ -30,24 +20,14 @@ from pcs.cli.common.parse_args import (
     Argv,
     InputModifiers,
     KeyValueParser,
-    ensure_unique_args,
     get_rule_str,
     group_by_keywords,
     wait_to_timeout,
 )
-from pcs.cli.common.tools import (
-    print_to_stderr,
-    timeout_to_seconds_legacy,
-)
-from pcs.cli.nvset import (
-    filter_out_expired_nvset,
-    nvset_dto_list_to_lines,
-)
+from pcs.cli.common.tools import print_to_stderr, timeout_to_seconds_legacy
+from pcs.cli.nvset import filter_out_expired_nvset, nvset_dto_list_to_lines
 from pcs.cli.reports import process_library_reports
-from pcs.cli.reports.output import (
-    error,
-    warn,
-)
+from pcs.cli.reports.output import error, warn
 from pcs.cli.resource.common import check_is_not_stonith
 from pcs.cli.resource.output import (
     operation_defaults_to_cmd,
@@ -63,39 +43,22 @@ from pcs.cli.resource.parse_args import (
     parse_create_old,
 )
 from pcs.cli.resource_agent import find_single_agent
-from pcs.common import (
-    const,
-    pacemaker,
-    reports,
-)
+from pcs.common import const, pacemaker, reports
 from pcs.common.interface import dto
 from pcs.common.pacemaker.defaults import CibDefaultsDto
-from pcs.common.pacemaker.resource.list import (
-    get_all_resources_ids,
-    get_stonith_resources_ids,
-)
 from pcs.common.pacemaker.resource.operations import (
     OCF_CHECK_LEVEL_INSTANCE_ATTRIBUTE_NAME,
 )
-from pcs.common.str_tools import (
-    format_list,
-    format_list_custom_last_separator,
-    format_plural,
-)
-from pcs.lib.cib.resource import (
-    guest_node,
-    primitive,
-)
+from pcs.common.str_tools import format_list_custom_last_separator
+from pcs.lib.cib import const as cib_const
+from pcs.lib.cib.resource import guest_node, primitive
 from pcs.lib.cib.tools import get_resources
 from pcs.lib.commands.resource import (
     _get_nodes_to_validate_against,
     _validate_guest_change,
 )
 from pcs.lib.errors import LibraryError
-from pcs.lib.pacemaker.values import (
-    is_true,
-    validate_id,
-)
+from pcs.lib.pacemaker.values import is_true, validate_id
 from pcs.settings import (
     pacemaker_wait_timeout_status as PACEMAKER_WAIT_TIMEOUT_STATUS,
 )
@@ -584,14 +547,12 @@ def resource_list_options(
         )
     print(
         "\n".join(
-            smart_wrap_text(
-                resource_agent_metadata_to_text(
-                    lib.resource_agent.get_agent_metadata(agent_name),
-                    lib.resource_agent.get_agent_default_operations(
-                        agent_name
-                    ).operations,
-                    verbose=modifiers.is_specified("--full"),
-                )
+            resource_agent_metadata_to_text(
+                lib.resource_agent.get_agent_metadata(agent_name),
+                lib.resource_agent.get_agent_default_operations(
+                    agent_name
+                ).operations,
+                verbose=modifiers.is_specified("--full"),
             )
         )
     )
@@ -1054,10 +1015,9 @@ def resource_update(args: Argv, modifiers: InputModifiers) -> None:  # noqa: PLR
 
     params = utils.convert_args_to_tuples(ra_values)
 
+    agent_name = _get_resource_agent_name_from_rsc_el(resource)
     try:
-        agent_facade = _get_resource_agent_facade(
-            _get_resource_agent_name_from_rsc_el(resource)
-        )
+        agent_facade = _get_resource_agent_facade(agent_name)
         report_list = primitive.validate_resource_instance_attributes_update(
             utils.cmd_runner(),
             agent_facade,
@@ -1089,7 +1049,7 @@ def resource_update(args: Argv, modifiers: InputModifiers) -> None:  # noqa: PLR
 
     # The "remote-node" meta attribute makes sense (and causes creation of
     # inner pacemaker resource) only for primitive. The meta attribute
-    # "remote-node" has no special meaining for clone/master. So there is no
+    # "remote-node" has no special meaning for clone/master. So there is no
     # need for checking this attribute in clone/master.
     #
     # It is ok to not to check it until this point in this function:
@@ -1105,6 +1065,15 @@ def resource_update(args: Argv, modifiers: InputModifiers) -> None:  # noqa: PLR
             bool(modifiers.get("--force")),
         )
 
+    # TODO: validation should be added after migrating the command to the new
+    # architecture
+    if any(meta_options.values()):
+        command = "stonith" if agent_name.is_stonith else "resource"
+        warn(
+            "Meta attributes are not validated by this command. For "
+            f"validation, please use 'pcs {command} meta' instead."
+        )
+
     utils.dom_update_meta_attr(
         resource, utils.convert_args_to_tuples(meta_values)
     )
@@ -1715,6 +1684,18 @@ def resource_clone_create(  # noqa: PLR0912
         clone.appendChild(element)
         resources_el.appendChild(clone)
 
+    # TODO: validation should be added after migrating the command to the new
+    # architecture
+    if any(
+        value
+        for name, value in parts.meta_attrs.items()
+        if name != "promotable" or not promotable
+    ):
+        warn(
+            reports.messages.MetaAttrsNotValidatedUnsupportedType(
+                [cib_const.TAG_RESOURCE_CLONE]
+            ).message
+        )
     utils.dom_update_meta_attr(clone, sorted(parts.meta_attrs.items()))
 
     return cib_dom, clone.getAttribute("id")
@@ -1874,49 +1855,6 @@ def resource_clone_master_remove(
             utils.err("\n".join(msg).strip())
 
 
-def resource_remove_cmd(
-    lib: Any, argv: Argv, modifiers: InputModifiers
-) -> None:
-    """
-    Options:
-      * -f - CIB file
-      * --force - don't stop resources before deletion
-    """
-    modifiers.ensure_only_supported("-f", "--force")
-    if not argv:
-        raise CmdLineInputError()
-    ensure_unique_args(argv)
-
-    resources_to_remove = set(argv)
-    resources_dto = lib.resource.get_configured_resources()
-    missing_ids = resources_to_remove - get_all_resources_ids(resources_dto)
-    if missing_ids:
-        raise CmdLineInputError(
-            "Unable to find {resource}: {id_list}".format(
-                resource=format_plural(missing_ids, "resource"),
-                id_list=format_list(missing_ids),
-            )
-        )
-
-    stonith_ids = resources_to_remove & get_stonith_resources_ids(resources_dto)
-    if stonith_ids:
-        raise CmdLineInputError(
-            (
-                "This command cannot remove stonith {resource}: {id_list}. Use "
-                "'pcs stonith remove' instead."
-            ).format(
-                resource=format_plural(stonith_ids, "resource"),
-                id_list=format_list(stonith_ids),
-            )
-        )
-
-    force_flags = set()
-    if modifiers.is_specified("--force"):
-        force_flags.add(reports.codes.FORCE)
-
-    lib.cib.remove_elements(resources_to_remove, force_flags)
-
-
 def stonith_level_rm_device(cib_dom, stn_id):
     """
     Commandline options: no options
@@ -2052,8 +1990,10 @@ def resource_group_list(
     element = parseString(group_xml).documentElement
     # If there is more than one group returned it's wrapped in an xpath-query
     # element
-    if element.tagName == "xpath-query":
-        elements = element.getElementsByTagName("group")
+    # Ignoring mypy errors in this very old code. So far, nobody reported a bug
+    # related to these lines.
+    if element.tagName == "xpath-query":  # type: ignore
+        elements = element.getElementsByTagName("group")  # type: ignore
     else:
         elements = [element]
 
