@@ -1,49 +1,39 @@
 # pylint: disable=too-many-lines
 import base64
+import fcntl
 import getpass
 import json
 import logging
 import os
 import re
 import signal
+import struct
 import subprocess
 import sys
 import tarfile
 import tempfile
+import termios
 import threading
 import time
 import xml.dom.minidom
 from functools import lru_cache
 from io import BytesIO
 from textwrap import dedent
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Optional,
-    Tuple,
-    cast,
-)
+from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple, cast
 from urllib.parse import urlencode
 from xml.dom.minidom import Document as DomDocument
 from xml.dom.minidom import parseString
 
 import pcs.cli.booth.env
 import pcs.lib.corosync.config_parser as corosync_conf_parser
-from pcs import (
-    settings,
-    usage,
-)
+from pcs import settings, usage
 from pcs.cli.cluster_property.output import PropertyConfigurationFacade
 from pcs.cli.common import middleware
 from pcs.cli.common.env_cli import Env
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.common.lib_wrapper import Library
 from pcs.cli.common.parse_args import InputModifiers
-from pcs.cli.common.tools import (
-    print_to_stderr,
-    timeout_to_seconds_legacy,
-)
+from pcs.cli.common.tools import print_to_stderr, timeout_to_seconds_legacy
 from pcs.cli.file import metadata as cli_file_metadata
 from pcs.cli.reports import ReportProcessorToConsole, process_library_reports
 from pcs.cli.reports import output as reports_output
@@ -60,18 +50,12 @@ from pcs.common.reports.messages import CibUpgradeFailedToMinimalRequiredVersion
 from pcs.common.services.errors import ManageServiceError
 from pcs.common.services.interfaces import ServiceManagerInterface
 from pcs.common.str_tools import format_list
-from pcs.common.tools import (
-    Version,
-    timeout_to_seconds,
-)
+from pcs.common.tools import Version, timeout_to_seconds
 from pcs.common.types import StringSequence
 from pcs.lib.corosync.config_facade import ConfigFacade as corosync_conf_facade
 from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
-from pcs.lib.external import (
-    CommandRunner,
-    is_proxy_set,
-)
+from pcs.lib.external import CommandRunner, is_proxy_set
 from pcs.lib.file.instance import FileInstance as LibFileInstance
 from pcs.lib.host.config.facade import Facade as KnownHostsFacade
 from pcs.lib.interface.config import ParserErrorException
@@ -990,65 +974,6 @@ def run_pcsdcli(command, data=None):
     return output_json, retval
 
 
-def auth_hosts_token(host_dict):
-    output, retval = run_pcsdcli("auth_with_token", dict(nodes=host_dict))
-    if retval == 0:
-        if output["status"] == "access_denied":
-            err("Access denied")
-        if output["status"] != "ok":
-            err("Unable to communicate with pcsd")
-    else:
-        err("Unable to communicate with pcsd")
-
-
-def auth_hosts(host_dict):
-    """
-    Commandline options:
-      * --request-timeout - timeout for HTTP request
-    """
-    output, retval = run_pcsdcli("auth", dict(nodes=host_dict))
-    if retval == 0 and output["status"] == "access_denied":
-        err("Access denied")
-    if retval == 0 and output["status"] == "ok" and output["data"]:
-        failed = False
-        try:
-            if not output["data"]["sync_successful"]:
-                err(
-                    "Some nodes had a newer known-hosts than the local node. "
-                    + "Local node's known-hosts were updated. "
-                    + "Please repeat the authentication if needed."
-                )
-            for node, result in output["data"]["auth_responses"].items():
-                if result["status"] == "ok":
-                    print_to_stderr(f"{node}: Authorized")
-                elif result["status"] == "bad_password":
-                    err(f"{node}: Username and/or password is incorrect", False)
-                    failed = True
-                elif result["status"] in ("noresponse", "error"):
-                    err("Unable to communicate with {0}".format(node), False)
-                    failed = True
-                else:
-                    err("Unexpected response from {0}".format(node), False)
-                    failed = True
-            if output["data"]["sync_nodes_err"]:
-                err(
-                    (
-                        "Unable to synchronize and save known-hosts on nodes: "
-                        + "{0}. Run 'pcs host auth {1}' to make sure the nodes "
-                        + "are authorized."
-                    ).format(
-                        ", ".join(output["data"]["sync_nodes_err"]),
-                        " ".join(output["data"]["sync_nodes_err"]),
-                    )
-                )
-        except (ValueError, KeyError):
-            err("Unable to communicate with pcsd")
-        if failed:
-            sys.exit(1)
-        return
-    err("Unable to communicate with pcsd")
-
-
 def call_local_pcsd(argv, options, std_in=None):  # noqa: PLR0911
     """
     Commandline options:
@@ -1871,11 +1796,6 @@ def getTerminalSize(fd=1):
     Commandline options: no options
     """
     try:
-        # pylint: disable=import-outside-toplevel
-        import fcntl
-        import struct
-        import termios
-
         hw = struct.unpack(
             str("hh"), fcntl.ioctl(fd, termios.TIOCGWINSZ, "1234")
         )
@@ -2623,7 +2543,7 @@ def get_report_processor() -> ReportProcessor:
     return ReportProcessorToConsole(debug="--debug" in pcs_options)
 
 
-def get_user_and_pass():
+def get_user_and_pass() -> tuple[str, str]:
     """
     Commandline options:
       * -u - username
@@ -2647,7 +2567,8 @@ def get_input_modifiers() -> InputModifiers:
 def get_token_from_file(file_name: str) -> str:
     try:
         with open(file_name, "rb") as file:
-            max_size = settings.pcsd_token_max_bytes  # type: ignore
+            # 256 to stay backwards compatible
+            max_size = 256
             value_bytes = file.read(max_size + 1)
             if len(value_bytes) > max_size:
                 err(f"Maximal token size of {max_size} bytes exceeded")
