@@ -5,7 +5,7 @@ from lxml import etree
 from pcs.lib.booth import cib as cib_commands
 
 
-class GetTicketNames(TestCase):
+class GetTicketNamesBase:
     def setUp(self):
         self.cib = etree.fromstring(
             """
@@ -23,6 +23,27 @@ class GetTicketNames(TestCase):
         """
         )
 
+
+class GetBoothTicketNames(GetTicketNamesBase, TestCase):
+    def test_default(self):
+        self.assertEqual(
+            ["T1", "T2"], cib_commands.get_booth_ticket_names(self.cib)
+        )
+
+    def test_custom_booth_name(self):
+        self.assertEqual(
+            ["T3"],
+            cib_commands.get_booth_ticket_names(self.cib, "custom_booth"),
+        )
+
+    def test_no_tickets(self):
+        self.assertEqual(
+            [],
+            cib_commands.get_booth_ticket_names(self.cib, "nonexistent_booth"),
+        )
+
+
+class GetTicketNames(GetTicketNamesBase, TestCase):
     def test_success(self):
         self.assertEqual(
             ["T1", "T2", "T3", "T-self-managed"],
