@@ -106,8 +106,8 @@ def corosync_node_fixture(node_id, node, addrs):
     ]
 
 
-def node_fixture(node, node_id, addr_sufix=""):
-    return corosync_node_fixture(node_id, node, [f"{node}{addr_sufix}"])
+def node_fixture(node, node_id, addr_suffix=""):
+    return corosync_node_fixture(node_id, node, [f"{node}{addr_suffix}"])
 
 
 class LocalConfig:
@@ -1589,6 +1589,9 @@ class FailureCorosyncReload(TestCase):
                     report_codes.COROSYNC_CONFIG_RELOADED,
                     node=self.nodes_to_stay[2],
                 ),
+                fixture.warn(
+                    report_codes.COROSYNC_CONFIG_INVALID_PREVENTS_CLUSTER_JOIN
+                ),
             ]
         )
 
@@ -1643,6 +1646,9 @@ class FailureCorosyncReload(TestCase):
                     report_codes.COROSYNC_CONFIG_RELOADED,
                     node=self.nodes_to_stay[2],
                 ),
+                fixture.warn(
+                    report_codes.COROSYNC_CONFIG_INVALID_PREVENTS_CLUSTER_JOIN
+                ),
             ]
         )
 
@@ -1732,11 +1738,12 @@ class FailureCorosyncReload(TestCase):
                     command=self.cmd_url,
                     reason=self.err_msg,
                 ),
-            ]
-            + [
+                fixture.warn(
+                    report_codes.COROSYNC_CONFIG_INVALID_PREVENTS_CLUSTER_JOIN
+                ),
                 fixture.error(
                     report_codes.UNABLE_TO_PERFORM_OPERATION_ON_ANY_NODE,
-                )
+                ),
             ]
         )
 
