@@ -217,7 +217,7 @@ class ParametrizedContainerMixin(SetUpMixin):
             ]
         )
 
-    def test_unknow_container_option(self):
+    def test_unknown_container_option(self):
         self.env_assist.assert_raise_library_error(
             lambda: self.run_bundle_cmd(
                 container_options={
@@ -244,7 +244,7 @@ class ParametrizedContainerMixin(SetUpMixin):
             ]
         )
 
-    def test_unknow_container_option_forced(self):
+    def test_unknown_container_option_forced(self):
         self.config.env.push_cib(
             resources="""
                 <resources>
@@ -914,6 +914,31 @@ class MetaMixin(SetUpMixin):
                 "is-managed": "false",
             }
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle"],
+                ),
+            ]
+        )
+
+    def test_empty_meta_attributes(self):
+        self.config.env.push_cib(
+            resources="""
+                <resources>
+                    <bundle id="{bundle_id}">
+                        <{container_type} image="{image}" />
+                    </bundle>
+                </resources>
+            """.format(
+                container_type=self.container_type,
+                bundle_id=self.bundle_id,
+                image=self.image,
+            )
+        )
+        self.run_bundle_cmd(meta_attributes={})
+        self.env_assist.assert_reports([])
 
     def test_disabled(self):
         self.config.env.push_cib(
@@ -1168,7 +1193,7 @@ class WaitMixin(FixturesMixin, SetUpMixin):
     @mock.patch.object(
         settings,
         "pacemaker_api_result_schema",
-        rc("pcmk_api_rng/api-result.rng"),
+        rc("pcmk_rng/api/api-result.rng"),
     )
     def test_wait_ok_run_ok(self):
         (
@@ -1189,7 +1214,7 @@ class WaitMixin(FixturesMixin, SetUpMixin):
     @mock.patch.object(
         settings,
         "pacemaker_api_result_schema",
-        rc("pcmk_api_rng/api-result.rng"),
+        rc("pcmk_rng/api/api-result.rng"),
     )
     def test_wait_ok_run_fail(self):
         (
@@ -1212,7 +1237,7 @@ class WaitMixin(FixturesMixin, SetUpMixin):
     @mock.patch.object(
         settings,
         "pacemaker_api_result_schema",
-        rc("pcmk_api_rng/api-result.rng"),
+        rc("pcmk_rng/api/api-result.rng"),
     )
     def test_disabled_wait_ok_run_ok(self):
         (
@@ -1239,7 +1264,7 @@ class WaitMixin(FixturesMixin, SetUpMixin):
     @mock.patch.object(
         settings,
         "pacemaker_api_result_schema",
-        rc("pcmk_api_rng/api-result.rng"),
+        rc("pcmk_rng/api/api-result.rng"),
     )
     def test_disabled_wait_ok_run_fail(self):
         (
