@@ -1,5 +1,6 @@
 from unittest import TestCase
 
+from pcs.common import reports
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 from pcs.lib.commands.resource import bundle_reset
@@ -71,7 +72,7 @@ class MinimalMixin(BaseMixin, SetUpMixin):
             container_options={"image": new_image},
         )
 
-    def test_noexistent_id(self):
+    def test_nonexistent_id(self):
         self.env_assist.assert_raise_library_error(
             lambda: self.bundle_reset(bundle_id="B0"),
             [
@@ -273,6 +274,14 @@ class FullMixin(SetUpMixin, BaseMixin):
                 "target-role": "Started",
             },
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle"],
+                ),
+            ]
+        )
 
     def test_success_keep_map_ids(self):
         self.config.env.push_cib(
@@ -346,6 +355,15 @@ class FullMixin(SetUpMixin, BaseMixin):
             },
         )
 
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle"],
+                ),
+            ]
+        )
+
 
 class ResetParametrizedContainerMixin(BaseMixin, ParametrizedContainerMixin):
     pass
@@ -419,6 +437,14 @@ class ResetWithMetaMap(BaseMixin, MetaMixin, TestCase):
                 "is-managed": "false",
             }
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle"],
+                ),
+            ]
+        )
 
 
 class ResetWithAllOptions(BaseMixin, AllOptionsMixin, TestCase):
@@ -500,6 +526,14 @@ class NoMetaIdRegenerationMixin(BaseMixin, SetUpMixin):
                 "target-role": "Stopped",
             },
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle"],
+                ),
+            ]
+        )
 
 
 class NoMetaIdRegenerationDocker(NoMetaIdRegenerationMixin, TestCase):
