@@ -209,7 +209,7 @@ class ContainerParametrized(TestCase):
             ]
         )
 
-    def _test_unknow_option(self):
+    def _test_unknown_option(self):
         self.config.runner.cib.load(
             resources=fixture_resources_minimal(self.container_type)
         )
@@ -240,7 +240,7 @@ class ContainerParametrized(TestCase):
             ]
         )
 
-    def _test_unknow_option_forced(self):
+    def _test_unknown_option_forced(self):
         (
             self.config.runner.cib.load(
                 resources=fixture_resources_minimal(self.container_type)
@@ -508,6 +508,14 @@ class ContainerUnknown(TestCase):
                 "attr": "val",
             },
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle"],
+                ),
+            ]
+        )
 
     def test_no_container_options(self):
         self.config.env.push_cib(
@@ -557,6 +565,14 @@ class ContainerUnknown(TestCase):
                 "host-netmask": "24",
             },
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle"],
+                ),
+            ]
+        )
 
     def test_with_container_options(self):
         self.env_assist.assert_raise_library_error(
@@ -714,7 +730,7 @@ class Network(TestCase):
             },
         )
 
-    def test_unknow_option(self):
+    def test_unknown_option(self):
         (self.config.runner.cib.load(resources=self.fixture_cib_interface))
         self.env_assist.assert_raise_library_error(
             lambda: resource.bundle_update(
@@ -743,7 +759,7 @@ class Network(TestCase):
             ]
         )
 
-    def test_unknow_option_forced(self):
+    def test_unknown_option_forced(self):
         (
             self.config.runner.cib.load(
                 resources=self.fixture_cib_interface
@@ -1147,6 +1163,22 @@ class Meta(TestCase):
                 "target-role": "Stopped",
             },
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle"],
+                ),
+            ]
+        )
+
+    def test_empty_meta_attributes(self):
+        self.config.runner.cib.load(resources=self.fixture_no_meta)
+        self.config.env.push_cib(resources=self.fixture_no_meta)
+        resource.bundle_update(
+            self.env_assist.get_env(), "B1", meta_attributes={}
+        )
+        self.env_assist.assert_reports([])
 
     def test_keep_meta_element(self):
         (
@@ -1207,6 +1239,14 @@ class Meta(TestCase):
                 "is-managed": "",
             },
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle"],
+                ),
+            ]
+        )
 
 
 class Wait(TestCase):
@@ -1297,7 +1337,7 @@ class Wait(TestCase):
     @mock.patch.object(
         settings,
         "pacemaker_api_result_schema",
-        rc("pcmk_api_rng/api-result.rng"),
+        rc("pcmk_rng/api/api-result.rng"),
     )
     def test_wait_ok_running(self):
         (
@@ -1318,7 +1358,7 @@ class Wait(TestCase):
     @mock.patch.object(
         settings,
         "pacemaker_api_result_schema",
-        rc("pcmk_api_rng/api-result.rng"),
+        rc("pcmk_rng/api/api-result.rng"),
     )
     def test_wait_ok_not_running(self):
         (
