@@ -6,13 +6,19 @@ from pcs.common import (
     reports,
 )
 from pcs.lib.commands import resource
+from pcs.lib.resource_agent.const import PRIMITIVE_META, STONITH_META
 from pcs.lib.resource_agent.types import ResourceAgentName
 
 from pcs_test.tools import fixture
 from pcs_test.tools.assertions import assert_raise_library_error
 from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.metadata_dto import (
+    FIXTURE_KNOWN_META_NAMES_PRIMITIVE_META,
+    FIXTURE_KNOWN_META_NAMES_STONITH_META,
+)
 
 _AGENT_NAME_PCMK_DUMMY = ResourceAgentName("ocf", "pacemaker", "Dummy")
+_AGENT_NAME_STONITH = ResourceAgentName("stonith", None, "Dummy")
 _AGENT_NAME_PCMK_STATEFUL = ResourceAgentName("ocf", "pacemaker", "Stateful")
 
 
@@ -148,7 +154,7 @@ class UpdateMeta(TestCase):
         self.env_assist, self.config = get_env_tools(test_case=self)
 
     def test_update_nonexistent_resource(self):
-        self.config.runner.cib.load(filename="cib-resources.xml")
+        self.config.runner.cib.load(filename="cib-all.xml")
         self.env_assist.assert_raise_library_error(
             lambda: resource.update_meta(
                 self.env_assist.get_env(), "Rx", {"priority": "1"}, []
@@ -193,6 +199,7 @@ class UpdateMeta(TestCase):
 
     def test_meta_attr_elem_missing(self):
         self.config.runner.cib.load(resources=fixture_primitive())
+        self.config.runner.pcmk.load_crm_resource_metadata()
         self.config.corosync_conf.load()
         self.config.env.push_cib(
             resources=fixture_primitive(
@@ -228,6 +235,7 @@ class UpdateMeta(TestCase):
                 """,
             )
         )
+        self.config.runner.pcmk.load_crm_resource_metadata()
         self.config.corosync_conf.load()
         self.config.env.push_cib(
             resources=fixture_primitive(
@@ -252,6 +260,7 @@ class UpdateMeta(TestCase):
         self.config.runner.cib.load(
             resources=fixture_primitive(),
         )
+        self.config.runner.pcmk.load_crm_resource_metadata()
         self.config.corosync_conf.load(node_name_list=["node1"])
         self.env_assist.assert_raise_library_error(
             lambda: resource.update_meta(
@@ -278,6 +287,7 @@ class UpdateMeta(TestCase):
         self.config.runner.cib.load(
             resources=fixture_primitive(),
         )
+        self.config.runner.pcmk.load_crm_resource_metadata()
         self.config.corosync_conf.load()
         self.config.env.push_cib(
             resources=fixture_primitive(
@@ -326,6 +336,14 @@ class UpdateMeta(TestCase):
             {"priority": "1", "promotable": ""},
             [],
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle", "clone"],
+                ),
+            ]
+        )
 
 
 class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
@@ -351,6 +369,14 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
         resource.update_meta(
             self.env_assist.get_env(), "A-clone", {"priority": "1"}, []
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle", "clone"],
+                ),
+            ]
+        )
 
     def test_success_cloned_primitive_promotable(self):
         self.config.runner.cib.load(
@@ -377,6 +403,14 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
         resource.update_meta(
             self.env_assist.get_env(), "A-clone", {"promotable": "true"}, []
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle", "clone"],
+                ),
+            ]
+        )
 
     def test_success_cloned_primitive_promotable_ocf_old(self):
         # Despite the test name, agent older than OCF 1.1 can be promoted
@@ -404,6 +438,14 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
         resource.update_meta(
             self.env_assist.get_env(), "A-clone", {"promotable": "true"}, []
         )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle", "clone"],
+                ),
+            ]
+        )
 
     def test_fail_cloned_primitive_promotable_incompatible(self):
         self.config.runner.cib.load(
@@ -424,6 +466,10 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
 
         self.env_assist.assert_reports(
             [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle", "clone"],
+                ),
                 fixture.error(
                     reports.codes.RESOURCE_CLONE_INCOMPATIBLE_META_ATTRIBUTES,
                     attribute="promotable",
@@ -431,7 +477,7 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
                     resource_id="A",
                     group_id=None,
                     force_code=reports.codes.FORCE,
-                )
+                ),
             ]
         )
 
@@ -461,13 +507,17 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
         )
         self.env_assist.assert_reports(
             [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle", "clone"],
+                ),
                 fixture.warn(
                     reports.codes.RESOURCE_CLONE_INCOMPATIBLE_META_ATTRIBUTES,
                     attribute="promotable",
                     resource_agent=_AGENT_NAME_PCMK_DUMMY.to_dto(),
                     resource_id="A",
                     group_id=None,
-                )
+                ),
             ]
         )
 
@@ -496,13 +546,17 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
         )
         self.env_assist.assert_reports(
             [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle", "clone"],
+                ),
                 fixture.error(
                     reports.codes.RESOURCE_CLONE_INCOMPATIBLE_META_ATTRIBUTES,
                     attribute=attr,
                     resource_agent=agent.to_dto(),
                     resource_id="non-ocf",
                     group_id=None,
-                )
+                ),
             ]
         )
 
@@ -535,6 +589,10 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
 
         self.env_assist.assert_reports(
             [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle", "clone"],
+                ),
                 fixture.error(
                     reports.codes.RESOURCE_CLONE_INCOMPATIBLE_META_ATTRIBUTES,
                     attribute="promotable",
@@ -542,7 +600,7 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
                     resource_id="A",
                     group_id="G",
                     force_code=reports.codes.FORCE,
-                )
+                ),
             ]
         )
 
@@ -573,13 +631,17 @@ class UpdateMetaCheckCloneIncompatibleMetaAttrs(TestCase):
         )
         self.env_assist.assert_reports(
             [
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_UNSUPPORTED_TYPE,
+                    meta_type_list=["bundle", "clone"],
+                ),
                 fixture.warn(
                     reports.codes.RESOURCE_CLONE_INCOMPATIBLE_META_ATTRIBUTES,
                     attribute="promotable",
                     resource_agent=_AGENT_NAME_PCMK_DUMMY.to_dto(),
                     resource_id="A",
                     group_id="G",
-                )
+                ),
             ]
         )
 
@@ -599,27 +661,35 @@ class UpdateMetaRemoveUpdatedGuestNode(TestCase):
     ):
         self.config.runner.cib.load(
             resources=fixture_primitive(
-                meta_nvpairs_xml=f"""
+                meta_nvpairs_xml=(
+                    f"""
                     <nvpair id="A-meta_attributes-remote-node"
                         name="remote-node" value="{old_node_addr}"
                     />
                 """
-                if old_node_addr
-                else "",
+                    if old_node_addr
+                    else ""
+                ),
             )
         )
+        # we do not want to read the metadata when we are not adding any new
+        # attributes
+        if new_node_addr:
+            self.config.runner.pcmk.load_crm_resource_metadata()
         self.config.corosync_conf.load()
         self.config.env.push_cib(
             resources=fixture_primitive(
                 # For removeal, we want to hack the fixture to get the meta
                 # attributes element without nvpairs
-                meta_nvpairs_xml=" "
-                if is_nvset_empty
-                else f"""
+                meta_nvpairs_xml=(
+                    " "
+                    if is_nvset_empty
+                    else f"""
                     <nvpair id="A-meta_attributes-remote-node"
                         name="remote-node" value="{new_node_addr}"
                     />
                 """
+                )
             )
         )
         if is_node_removed:
@@ -638,15 +708,19 @@ class UpdateMetaRemoveUpdatedGuestNode(TestCase):
     ):
         self.config.runner.cib.load(
             resources=fixture_primitive(
-                meta_nvpairs_xml=f"""
+                meta_nvpairs_xml=(
+                    f"""
                     <nvpair id="A-meta_attributes-remote-node"
                         name="remote-node" value="{old_node_addr}"
                     />
                 """
-                if old_node_addr
-                else "",
+                    if old_node_addr
+                    else ""
+                ),
             )
         )
+        if new_node_addr:
+            self.config.runner.pcmk.load_crm_resource_metadata()
         self.config.corosync_conf.load()
         env = self.env_assist.get_env()
         assert_raise_library_error(
@@ -756,3 +830,160 @@ class UpdateMetaRemoveUpdatedGuestNode(TestCase):
                 ),
             ],
         )
+
+
+class UpdateMetaValidateMetaAttributes(TestCase):
+    def setUp(self):
+        self.env_assist, self.config = get_env_tools(test_case=self)
+
+    def test_primitive_invalid_meta_attribute_name(self):
+        self.config.runner.cib.load(resources=fixture_primitive())
+        self.config.runner.pcmk.load_crm_resource_metadata()
+        self.config.corosync_conf.load()
+        self.config.env.push_cib(
+            resources=fixture_primitive(
+                meta_nvpairs_xml="""
+                    <nvpair id="A-meta_attributes-name"
+                        name="name" value="value"
+                    />
+                """,
+            )
+        )
+
+        resource.update_meta(
+            self.env_assist.get_env(), "A", {"name": "value"}, []
+        )
+
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_UNKNOWN_TO_PCMK,
+                    unknown_meta=["name"],
+                    known_meta=FIXTURE_KNOWN_META_NAMES_PRIMITIVE_META,
+                    meta_types=[PRIMITIVE_META],
+                )
+            ]
+        )
+
+    def test_primitive_invalid_stonith_meta_attribute_name(self):
+        self.config.runner.cib.load(resources=fixture_primitive())
+        self.config.runner.pcmk.load_crm_resource_metadata()
+        self.config.corosync_conf.load()
+        self.config.env.push_cib(
+            resources=fixture_primitive(
+                meta_nvpairs_xml="""
+                    <nvpair id="A-meta_attributes-provides"
+                        name="provides" value="everything"
+                    />
+                """,
+            )
+        )
+
+        resource.update_meta(
+            self.env_assist.get_env(), "A", {"provides": "everything"}, []
+        )
+
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_UNKNOWN_TO_PCMK,
+                    unknown_meta=["provides"],
+                    known_meta=FIXTURE_KNOWN_META_NAMES_PRIMITIVE_META,
+                    meta_types=[PRIMITIVE_META],
+                )
+            ]
+        )
+
+    def test_group_invalid_stonith_meta_attribute_name(self):
+        self.config.runner.cib.load(resources=fixture_primitive())
+        self.config.runner.pcmk.load_crm_resource_metadata()
+        self.config.corosync_conf.load()
+        self.config.env.push_cib(
+            resources=fixture_primitive(
+                meta_nvpairs_xml="""
+                    <nvpair id="A-meta_attributes-provides"
+                        name="provides" value="everything"
+                    />
+                """,
+            )
+        )
+
+        resource.update_meta(
+            self.env_assist.get_env(), "A", {"provides": "everything"}, []
+        )
+
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_UNKNOWN_TO_PCMK,
+                    unknown_meta=["provides"],
+                    known_meta=FIXTURE_KNOWN_META_NAMES_PRIMITIVE_META,
+                    meta_types=[PRIMITIVE_META],
+                )
+            ]
+        )
+
+    def test_stonith_invalid_meta_attribute_name(self):
+        self.config.runner.cib.load(
+            resources=fixture_primitive(resource_agent=_AGENT_NAME_STONITH)
+        )
+        self.config.runner.pcmk.load_crm_resource_metadata()
+        self.config.corosync_conf.load()
+        self.config.env.push_cib(
+            resources=fixture_primitive(
+                resource_agent=_AGENT_NAME_STONITH,
+                meta_nvpairs_xml="""
+                    <nvpair id="A-meta_attributes-name"
+                        name="name" value="value"
+                    />
+                """,
+            )
+        )
+
+        resource.update_meta(
+            self.env_assist.get_env(), "A", {"name": "value"}, []
+        )
+
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_UNKNOWN_TO_PCMK,
+                    unknown_meta=["name"],
+                    known_meta=FIXTURE_KNOWN_META_NAMES_STONITH_META,
+                    meta_types=[STONITH_META],
+                )
+            ]
+        )
+
+    def test_primitive_error_loading_metadata(self):
+        self.config.runner.cib.load(resources=fixture_primitive())
+        self.config.runner.pcmk.load_crm_resource_metadata(
+            stdout="output", returncode=1
+        )
+        self.config.corosync_conf.load()
+        self.config.env.push_cib(
+            resources=fixture_primitive(
+                meta_nvpairs_xml="""
+                    <nvpair id="A-meta_attributes-name"
+                        name="name" value="value"
+                    />
+                """,
+            )
+        )
+
+        resource.update_meta(
+            self.env_assist.get_env(), "A", {"name": "value"}, []
+        )
+
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.UNABLE_TO_GET_AGENT_METADATA,
+                    agent="primitive-meta",
+                    reason="output",
+                ),
+                fixture.warn(
+                    reports.codes.META_ATTRS_NOT_VALIDATED_LOADING_ERROR
+                ),
+            ]
+        )
