@@ -17,9 +17,11 @@ from pcs.common.resource_agent.dto import (
 )
 from pcs.lib.commands import resource_agent as lib
 from pcs.lib.resource_agent import ResourceAgentName
+from pcs.lib.resource_agent import const as ra_const
 
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.metadata_dto import get_fixture_meta_attributes_dto
 
 
 def _operation_fixture(name, interval="", role=None, timeout=None):
@@ -1205,3 +1207,42 @@ class GetAgentDefaultOperations(TestCase):
 
     def test_stonith_only_necessary(self):
         self._test_stonith(True)
+
+
+class GetMetaAttributesMetadata(TestCase):
+    def setUp(self):
+        self.env_assist, self.config = get_env_tools(test_case=self)
+        self.maxDiff = None
+
+    def _test_success(self, resource_type):
+        self.config.runner.pcmk.load_crm_resource_metadata()
+        self.assertEqual(
+            lib.get_meta_attributes_metadata(
+                self.env_assist.get_env(), resource_type
+            ).parameters,
+            get_fixture_meta_attributes_dto(
+                agent_name=resource_type
+            ).parameters,
+        )
+
+    def test_success_primitive_meta(self):
+        self._test_success(resource_type=ra_const.PRIMITIVE_META)
+
+    def test_success_stonith_meta(self):
+        self._test_success(resource_type=ra_const.STONITH_META)
+
+    def test_metadata_load_error(self):
+        self.env_assist.assert_raise_library_error(
+            lambda: lib.get_meta_attributes_metadata(
+                self.env_assist.get_env(), "unknown"
+            )
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    report_codes.UNABLE_TO_GET_AGENT_METADATA,
+                    agent="unknown",
+                    reason="Unknown agent",
+                )
+            ]
+        )
