@@ -41,6 +41,9 @@ def _booth_config_path_fixture(instance_name="booth"):
     return os.path.join(settings.booth_config_dir, f"{instance_name}.conf")
 
 
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
+)
 class PacemakerStatusXml(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
@@ -152,9 +155,6 @@ class FullClusterStatusPlaintextBase(TestCase):
             """
         )
         self._fixture_config_crm_verify(self._fixture_crm_verify_success())
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
 
     def _fixture_config_live_remote_minimal(self):
         self.config.runner.pcmk.load_state_plaintext(
@@ -170,9 +170,6 @@ class FullClusterStatusPlaintextBase(TestCase):
             """,
         )
         self._fixture_config_crm_verify(self._fixture_crm_verify_success())
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
 
     def _fixture_config_local_daemons(  # noqa: PLR0913
         self,
@@ -244,7 +241,7 @@ class FullClusterStatusPlaintextBase(TestCase):
 @mock.patch("pcs.settings.booth_enable_authfile_set_enabled", False)
 @mock.patch("pcs.settings.booth_enable_authfile_unset_enabled", False)
 @mock.patch.object(
-    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
 )
 class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
     # pylint: disable=too-many-public-methods
@@ -381,9 +378,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
         self.config.runner.pcmk.load_ticket_state_plaintext(
             stdout="ticket status"
         )
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons()
         self.config.http.host.check_reachability(
             node_labels=self.node_name_list
@@ -459,9 +453,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
         self.config.runner.pcmk.load_ticket_state_plaintext(
             stdout="ticket status"
         )
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons(
             corosync_enabled=False,
             corosync_active=False,
@@ -584,9 +575,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
         self.config.runner.pcmk.load_ticket_state_plaintext(
             stdout="ticket status"
         )
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons()
         self.config.http.host.check_reachability(
             node_labels=self.node_name_list
@@ -638,9 +626,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
         self.config.runner.pcmk.load_ticket_state_plaintext(
             stdout="ticket stdout", stderr=stderr, returncode=1
         )
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons()
         self.config.http.host.check_reachability(
             node_labels=self.node_name_list
@@ -703,9 +688,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
             self._fixture_crm_verify_invalid_cib(errors),
             retval=EXITCODE_INVALID_CIB,
         )
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons()
         self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
 
@@ -746,9 +728,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
         self.config.runner.pcmk.verify_xml(
             stdout="not a xml", stderr="some message"
         )
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons()
         self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
 
@@ -778,66 +757,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
             ]
         )
 
-    def test_stonith_warning_no_devices(self):
-        self.config.runner.pcmk.load_state_plaintext(
-            stdout="crm_mon cluster status"
-        )
-        self.config.fs.exists(settings.corosync_conf_file, return_value=True)
-        self.config.corosync_conf.load()
-        self.config.runner.cib.load()
-        self._fixture_config_crm_verify(self._fixture_crm_verify_success())
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
-        self._fixture_config_local_daemons()
-        self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
-
-        self.assertEqual(
-            status.full_cluster_status_plaintext(self.env_assist.get_env()),
-            dedent(
-                """\
-                Cluster name: test99
-
-                WARNINGS:
-                No stonith devices and stonith-enabled is not false
-
-                crm_mon cluster status
-
-                Daemon Status:
-                  corosync: active/enabled
-                  pacemaker: active/enabled
-                  pcsd: active/enabled"""
-            ),
-        )
-
-    def test_stonith_warning_no_devices_sbd_enabled(self):
-        self.config.runner.pcmk.load_state_plaintext(
-            stdout="crm_mon cluster status"
-        )
-        self.config.fs.exists(settings.corosync_conf_file, return_value=True)
-        self.config.corosync_conf.load()
-        self.config.runner.cib.load()
-        self._fixture_config_crm_verify(self._fixture_crm_verify_success())
-        self.config.services.is_running(
-            "sbd", return_value=True, name="services.is_running.sbd"
-        )
-        self._fixture_config_local_daemons()
-        self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
-
-        self.assertEqual(
-            status.full_cluster_status_plaintext(self.env_assist.get_env()),
-            dedent(
-                """\
-                Cluster name: test99
-                crm_mon cluster status
-
-                Daemon Status:
-                  corosync: active/enabled
-                  pacemaker: active/enabled
-                  pcsd: active/enabled"""
-            ),
-        )
-
     def test_stonith_warnings_regarding_devices_configuration(self):
         self.config.runner.pcmk.load_state_plaintext(
             stdout="crm_mon cluster status"
@@ -869,13 +788,15 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
                             <nvpair name="method" value="cycle" />
                         </instance_attributes>
                     </primitive>
+                    <primitive id="S5" class="stonith" type="fence_heuristics_ping">
+                        <instance_attributes>
+                            <nvpair name="method" value="cycle" />
+                        </instance_attributes>
+                    </primitive>
                 </resources>
             """
         )
         self._fixture_config_crm_verify(self._fixture_crm_verify_success())
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons()
         self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
 
@@ -918,9 +839,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
         self.config.runner.pcmk.load_ticket_state_plaintext(
             stdout="ticket status"
         )
-        self.config.services.is_running(
-            "sbd", return_value=False, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons()
         self.config.http.host.check_reachability(
             communication_list=[
@@ -1057,9 +975,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
             """,
         )
         self._fixture_config_crm_verify(self._fixture_crm_verify_success())
-        self.config.services.is_running(
-            "sbd", return_value=True, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons(sbd_enabled=True, sbd_active=True)
         self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
 
@@ -1117,9 +1032,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
             """,
         )
         self._fixture_config_crm_verify(self._fixture_crm_verify_success())
-        self.config.services.is_running(
-            "sbd", return_value=True, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons(sbd_enabled=True, sbd_active=True)
         self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
         self.config.runner.pcmk.get_rule_in_effect_status(
@@ -1187,9 +1099,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
             """,
         )
         self._fixture_config_crm_verify(self._fixture_crm_verify_success())
-        self.config.services.is_running(
-            "sbd", return_value=True, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons(sbd_enabled=True, sbd_active=True)
         self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
         self.config.runner.pcmk.get_rule_in_effect_status(
@@ -1242,9 +1151,6 @@ class FullClusterStatusPlaintext(FullClusterStatusPlaintextBase):
             """,
         )
         self._fixture_config_crm_verify(self._fixture_crm_verify_success())
-        self.config.services.is_running(
-            "sbd", return_value=True, name="services.is_running.sbd"
-        )
         self._fixture_config_local_daemons(sbd_enabled=True, sbd_active=True)
         self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
 
@@ -1273,7 +1179,7 @@ class FullClusterStatusPlaintextBoothWarning(FullClusterStatusPlaintextBase):
         super().setUp()
         self.settings_patcher = mock.patch(
             "pcs.settings.pacemaker_api_result_schema",
-            rc("pcmk_api_rng/api-result.rng"),
+            rc("pcmk_rng/api/api-result.rng"),
         )
         self.settings_patcher.start()
         self._fixture_config_live_minimal()
@@ -1466,7 +1372,7 @@ def _fixture_primitive_resource_dto(
 @mock.patch.object(
     settings,
     "pacemaker_api_result_schema",
-    rc("pcmk_api_rng/api-result.rng"),
+    rc("pcmk_rng/api/api-result.rng"),
 )
 class ResourcesStatus(TestCase):
     def setUp(self):
