@@ -47,7 +47,7 @@ class GetClusterStatusMixin(TestCase):
 
 
 @mock.patch.object(
-    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
 )
 class GetClusterStatusXml(GetClusterStatusMixin, TestCase):
     # pylint: disable=protected-access
@@ -120,7 +120,7 @@ class GetClusterStatusXml(GetClusterStatusMixin, TestCase):
 
 
 @mock.patch.object(
-    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
 )
 class GetClusterStatusDom(GetClusterStatusMixin, TestCase):
     def test_success(self):
@@ -551,7 +551,7 @@ class Verify(TestCase):
 
 
 @mock.patch.object(
-    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
 )
 class GetCibVerificationErrors(TestCase):
     fixture_ok = """
@@ -1081,7 +1081,7 @@ class GetLocalNodeName(TestCase):
 
 
 @mock.patch.object(
-    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
 )
 class GetLocalNodeStatusTest(TestCase):
     def setUp(self):
@@ -1370,7 +1370,7 @@ class ResourceCleanupTest(TestCase):
 
 
 @mock.patch.object(
-    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
 )
 class ResourceRefreshTest(TestCase):
     def setUp(self):
@@ -1636,7 +1636,7 @@ class GetRulesInEffectStatus(TestCase):
 
 
 @mock.patch.object(
-    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
 )
 class GetResourceDigests(TestCase):
     DIGESTS = {
@@ -1727,7 +1727,7 @@ class GetResourceDigests(TestCase):
         runner.run.assert_called_once_with(call_args)
 
     def fixture_result_dict(self, digest_types=()):
-        result_dict = {k: None for k in self.DIGESTS}
+        result_dict = dict.fromkeys(self.DIGESTS)
         for digest_type in digest_types:
             result_dict[digest_type] = self.DIGESTS[digest_type]
         return result_dict
@@ -1864,12 +1864,13 @@ class HandleInstanceAttributesValidateViaPcmkTest(TestCase):
             base_cmd + ["--option", "attr1=val1", "--option", "attr2=val2"]
         )
 
-    def test_failure_empty_result(self):
+    def test_failure_empty_result_reads_from_stdout(self):
+        # workaround for fence_xvm outputting the validation errors to stdout
         runner = get_runner(
             stdout="""
             <api>
               <result>
-                <output source="stdout">this is ignored</output>
+                <output source="stdout">this is not ignored</output>
               </result>
             </api>
             """,
@@ -1886,7 +1887,7 @@ class HandleInstanceAttributesValidateViaPcmkTest(TestCase):
             {"attr1": "val1", "attr2": "val2"},
         )
         self.assertFalse(is_valid)
-        self.assertEqual(reason, "")
+        self.assertEqual(reason, "this is not ignored")
         runner.run.assert_called_once_with(
             base_cmd + ["--option", "attr1=val1", "--option", "attr2=val2"]
         )
