@@ -68,7 +68,7 @@ class ChildrenTest(TestCase):
 
 
 @mock.patch.object(
-    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
 )
 class WorkWithClusterStatusNodesTest(TestCase):
     def test_can_get_node_names(self):
@@ -114,7 +114,7 @@ class WorkWithClusterStatusNodesTest(TestCase):
 
 
 @mock.patch.object(
-    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+    settings, "pacemaker_api_result_schema", rc("pcmk_rng/api/api-result.rng")
 )
 class WorkWithClusterStatusSummaryTest(TestCase):
     def test_nodes_count(self):
