@@ -1,7 +1,4 @@
-from unittest import (
-    TestCase,
-    mock,
-)
+from unittest import TestCase, mock
 
 from lxml import etree
 
@@ -9,11 +6,14 @@ from pcs.common import reports
 from pcs.common.services.interfaces import ServiceManagerInterface
 from pcs.lib import cluster_property as lib_cluster_property
 from pcs.lib.cib.tools import IdProvider
-from pcs.lib.resource_agent.facade import ResourceAgentFacade
-from pcs.lib.resource_agent.types import (
+from pcs.lib.pacemaker import values as packemaker_values
+from pcs.lib.resource_agent import (
+    ResourceAgentFacade,
     ResourceAgentMetadata,
+    ResourceAgentName,
     ResourceAgentParameter,
 )
+from pcs.lib.resource_agent import const as ra_const
 from pcs.lib.xml_tools import etree_to_str
 
 from pcs_test.tools import fixture
@@ -58,32 +58,44 @@ FORBIDDEN_OPTIONS_LIST = [
 ]
 
 PARAMETER_DEFINITIONS = [
-    ("bool_param", "bool", "false", None),
-    ("integer_param", "integer", "9", None),
-    ("percentage_param", "percentage", "80%", None),
-    ("select_param", "select", "s1", ["s1", "s2", "s3"]),
-    ("time_param", "time", "30s", None),
-    ("stonith-watchdog-timeout", "time", "0", None),
-    ("cluster-infrastructure", "string", "corosync", None),
-    ("cluster-name", "string", "(null)", None),
-    ("dc-version", "string", "none", None),
-    ("have-watchdog", "boolean", "false", None),
-    ("duration_param", "duration", "P15S", None),
-    ("nonnegative_param", "nonnegative_integer", "9", None),
-    ("port_param", "port", "1234", None),
-    ("score_param", "score", "INFINITY", None),
-    ("timeout_param", "timeout", "60s", None),
+    ("bool_param", "bool", "false", None, []),
+    ("integer_param", "integer", "9", None, []),
+    ("percentage_param", "percentage", "80%", None, []),
+    ("select_param", "select", "s1", ["s1", "s2", "s3"], []),
+    ("time_param", "time", "30s", None, []),
+    (
+        "stonith-watchdog-timeout",
+        "time",
+        "0",
+        None,
+        ["fencing-watchdog-timeout"],
+    ),
+    ("fencing-watchdog-timeout", "time", "0", None, []),
+    ("stonith-enabled", "boolean", "true", None, []),
+    ("fencing-enabled", "boolean", "true", None, []),
+    ("cluster-infrastructure", "string", "corosync", None, []),
+    ("cluster-name", "string", "(null)", None, []),
+    ("dc-version", "string", "none", None, []),
+    ("have-watchdog", "boolean", "false", None, []),
+    ("duration_param", "duration", "P15S", None, []),
+    ("nonnegative_param", "nonnegative_integer", "9", None, []),
+    ("port_param", "port", "1234", None, []),
+    ("score_param", "score", "INFINITY", None, []),
+    ("timeout_param", "timeout", "60s", None, []),
 ]
 
 ALLOWED_PROPERTIES = [
     "bool_param",
     "duration_param",
+    "fencing-enabled",
+    "fencing-watchdog-timeout",
     "integer_param",
     "nonnegative_param",
     "percentage_param",
     "port_param",
     "score_param",
     "select_param",
+    "stonith-enabled",
     "stonith-watchdog-timeout",
     "time_param",
     "timeout_param",
@@ -98,7 +110,6 @@ FIXTURE_VALID_OPTIONS_DICT = {
     "port_param": "1234",
     "score_param": "-INFINITY",
     "select_param": "s3",
-    "stonith-watchdog-timeout": "0",
     "time_param": "5min",
     "timeout_param": "5",
 }
@@ -119,9 +130,13 @@ FIXTURE_INVALID_OPTIONS_DICT = {
 }
 
 STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES = ["", "0", "0s"]
+STONITH_WATCHDOG_TIMEOUT_PROPERTIES = [
+    "stonith-watchdog-timeout",
+    "fencing-watchdog-timeout",
+]
 
 
-def _fixture_parameter(name, param_type, default, enum_values):
+def _fixture_parameter(name, param_type, default, enum_values, deprecated_by):
     return ResourceAgentParameter(
         name,
         shortdesc=None,
@@ -131,8 +146,8 @@ def _fixture_parameter(name, param_type, default, enum_values):
         enum_values=enum_values,
         required=False,
         advanced=False,
-        deprecated=False,
-        deprecated_by=[],
+        deprecated=bool(deprecated_by),
+        deprecated_by=deprecated_by,
         deprecated_desc=None,
         unique_group=None,
         reloadable=False,
@@ -144,6 +159,12 @@ FIXTURE_PARAMETER_LIST = [
 ]
 
 
+FIXTURE_WATCHDOG_TIMEOUT_DEPRECATION_REPORT = fixture.warn(
+    reports.codes.DEPRECATED_OPTION,
+    option_name="stonith-watchdog-timeout",
+    replaced_by=["fencing-watchdog-timeout"],
+    option_type="cluster property",
+)
 FIXTURE_ERROR_REPORTS = [
     fixture.error(
         reports.codes.INVALID_OPTIONS,
@@ -263,26 +284,22 @@ class TestValidateSetClusterProperties(TestCase):
     # pylint: disable=too-many-public-methods
     def setUp(self):
         self.mock_service_manager = mock.Mock(spec=ServiceManagerInterface)
-        self.mock_facade_list = [
-            mock.Mock(
-                spec=ResourceAgentFacade,
-                metadata=mock.Mock(
-                    spec=ResourceAgentMetadata,
-                    parameters=FIXTURE_PARAMETER_LIST[
-                        0 : int(len(FIXTURE_PARAMETER_LIST) / 2)
-                    ],
+        self.facade = ResourceAgentFacade(
+            ResourceAgentMetadata(
+                ResourceAgentName(
+                    standard=ra_const.FAKE_AGENT_STANDARD,
+                    provider=None,
+                    type=ra_const.CLUSTER_OPTIONS,
                 ),
-            ),
-            mock.Mock(
-                spec=ResourceAgentFacade,
-                metadata=mock.Mock(
-                    spec=ResourceAgentMetadata,
-                    parameters=FIXTURE_PARAMETER_LIST[
-                        int(len(FIXTURE_PARAMETER_LIST) / 2) :
-                    ],
-                ),
-            ),
-        ]
+                True,
+                ra_const.OCF_1_1,
+                "shortdesc",
+                "longdesc",
+                FIXTURE_PARAMETER_LIST,
+                [],
+            )
+        )
+
         self.patcher_is_sbd_enabled = mock.patch("pcs.lib.sbd.is_sbd_enabled")
         self.patcher_sbd_devices = mock.patch(
             "pcs.lib.sbd.get_local_sbd_device_list"
@@ -311,14 +328,25 @@ class TestValidateSetClusterProperties(TestCase):
         valid_value=True,
         returncode=0,
     ):
-        # pylint: disable=too-many-arguments
+        calls_is_sbd_enabled = []
+        calls_sbd_devices = []
+        calls_sbd_timeout = []
+        self.mock_is_sbd_enabled.reset_mock()
+        self.mock_sbd_devices.reset_mock()
+        self.mock_sbd_timeout.reset_mock()
+
         self.mock_is_sbd_enabled.return_value = sbd_enabled
         self.mock_sbd_devices.return_value = ["devices"] if sbd_devices else []
         self.mock_sbd_timeout.return_value = 10
+        if "stonith-watchdog-timeout" in new_properties:
+            expected_report_list = [
+                FIXTURE_WATCHDOG_TIMEOUT_DEPRECATION_REPORT
+            ] + expected_report_list
+
         assert_report_item_list_equal(
             lib_cluster_property.validate_set_cluster_properties(
                 get_runner_mock(returncode=returncode),
-                self.mock_facade_list,
+                self.facade,
                 "property-set-id",
                 configured_properties,
                 new_properties,
@@ -327,38 +355,39 @@ class TestValidateSetClusterProperties(TestCase):
             ),
             expected_report_list,
         )
-        if (
-            "stonith-watchdog-timeout" in new_properties
-            and (
-                new_properties["stonith-watchdog-timeout"]
-                or "stonith-watchdog-timeout" in configured_properties
-            )
-            and valid_value
-        ):
-            self.mock_is_sbd_enabled.assert_called_once_with(
-                self.mock_service_manager
-            )
-            if sbd_enabled:
-                self.mock_sbd_devices.assert_called_once_with()
-                if sbd_devices or (
-                    new_properties["stonith-watchdog-timeout"]
-                    in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES
-                ):
-                    self.mock_sbd_timeout.assert_not_called()
-                else:
-                    self.mock_sbd_timeout.assert_called_once_with()
-                self.mock_sbd_devices.reset_mock()
-            else:
-                self.mock_sbd_devices.assert_not_called()
-                self.mock_sbd_timeout.assert_not_called()
-        else:
-            self.mock_is_sbd_enabled.assert_not_called()
-            self.mock_sbd_devices.assert_not_called()
-            self.mock_sbd_timeout.assert_not_called()
 
-        self.mock_is_sbd_enabled.reset_mock()
-        self.mock_sbd_devices.reset_mock()
-        self.mock_sbd_timeout.reset_mock()
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            if (
+                prop_name in new_properties
+                and (
+                    new_properties[prop_name]
+                    or prop_name in configured_properties
+                )
+                and valid_value
+            ):
+                calls_is_sbd_enabled.append(
+                    mock.call(self.mock_service_manager)
+                )
+                if sbd_enabled:
+                    calls_sbd_devices.append(mock.call())
+                    if not sbd_devices and (
+                        new_properties[prop_name]
+                        not in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES
+                    ):
+                        calls_sbd_timeout.append(mock.call())
+
+        self.mock_is_sbd_enabled.assert_has_calls(calls_is_sbd_enabled)
+        self.mock_sbd_devices.assert_has_calls(calls_sbd_devices)
+        self.mock_sbd_timeout.assert_has_calls(calls_sbd_timeout)
+        self.assertEqual(
+            self.mock_is_sbd_enabled.call_count, len(calls_is_sbd_enabled)
+        )
+        self.assertEqual(
+            self.mock_sbd_devices.call_count, len(calls_sbd_devices)
+        )
+        self.assertEqual(
+            self.mock_sbd_timeout.call_count, len(calls_sbd_timeout)
+        )
 
     def test_no_properties_to_set_or_unset(self):
         self.assert_validate_set(
@@ -411,92 +440,99 @@ class TestValidateSetClusterProperties(TestCase):
         )
 
     def test_unset_stonith_watchdog_timeout_sbd_disabled(self):
-        for value in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES:
-            with self.subTest(value=value):
-                self.assert_validate_set(
-                    ["stonith-watchdog-timeout"],
-                    {"stonith-watchdog-timeout": value},
-                    [],
-                )
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            for value in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES:
+                with self.subTest(property=prop_name, value=value):
+                    self.assert_validate_set(
+                        [prop_name], {prop_name: value}, []
+                    )
 
     def test_set_stonith_watchdog_timeout_sbd_disabled(self):
-        self.assert_validate_set(
-            [],
-            {"stonith-watchdog-timeout": "5"},
-            [
-                fixture.error(
-                    reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_SET,
-                    reason="sbd_not_set_up",
-                )
-            ],
-        )
-
-    def test_set_ok_stonith_watchdog_timeout_sbd_enabled_without_devices(self):
-        for value in ["15", "15s"]:
-            with self.subTest(value=value):
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            with self.subTest(property=prop_name):
                 self.assert_validate_set(
                     [],
-                    {"stonith-watchdog-timeout": value},
-                    [],
-                    sbd_enabled=True,
+                    {prop_name: "5"},
+                    [
+                        fixture.error(
+                            reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_SET,
+                            reason="sbd_not_set_up",
+                        )
+                    ],
                 )
 
+    def test_set_ok_stonith_watchdog_timeout_sbd_enabled_without_devices(self):
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            for value in ["15", "15s"]:
+                with self.subTest(property=prop_name, value=value):
+                    self.assert_validate_set(
+                        [],
+                        {prop_name: value},
+                        [],
+                        sbd_enabled=True,
+                    )
+
     def test_set_small_stonith_watchdog_timeout_sbd_enabled_without_devices(
         self,
     ):
-        self.assert_validate_set(
-            [],
-            {"stonith-watchdog-timeout": "9s"},
-            [
-                fixture.error(
-                    reports.codes.STONITH_WATCHDOG_TIMEOUT_TOO_SMALL,
-                    force_code=reports.codes.FORCE,
-                    cluster_sbd_watchdog_timeout=10,
-                    entered_watchdog_timeout="9s",
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            with self.subTest(property=prop_name):
+                self.assert_validate_set(
+                    [],
+                    {prop_name: "9s"},
+                    [
+                        fixture.error(
+                            reports.codes.STONITH_WATCHDOG_TIMEOUT_TOO_SMALL,
+                            force_code=reports.codes.FORCE,
+                            cluster_sbd_watchdog_timeout=10,
+                            entered_watchdog_timeout="9s",
+                        )
+                    ],
+                    sbd_enabled=True,
                 )
-            ],
-            sbd_enabled=True,
-        )
 
     def test_set_small_stonith_watchdog_timeout_sbd_enabled_without_devices_forced(
         self,
     ):
-        self.assert_validate_set(
-            [],
-            {"stonith-watchdog-timeout": "9"},
-            [
-                fixture.warn(
-                    reports.codes.STONITH_WATCHDOG_TIMEOUT_TOO_SMALL,
-                    cluster_sbd_watchdog_timeout=10,
-                    entered_watchdog_timeout="9",
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            with self.subTest(property=prop_name):
+                self.assert_validate_set(
+                    [],
+                    {prop_name: "9"},
+                    [
+                        fixture.warn(
+                            reports.codes.STONITH_WATCHDOG_TIMEOUT_TOO_SMALL,
+                            cluster_sbd_watchdog_timeout=10,
+                            entered_watchdog_timeout="9",
+                        )
+                    ],
+                    sbd_enabled=True,
+                    force=True,
                 )
-            ],
-            sbd_enabled=True,
-            force=True,
-        )
 
     def _set_invalid_value_stonith_watchdog_timeout(
         self, sbd_enabled=False, sbd_devices=False
     ):
-        for value in ["invalid", "10x"]:
-            with self.subTest(value=value):
-                self.assert_validate_set(
-                    [],
-                    {"stonith-watchdog-timeout": value},
-                    [
-                        fixture.error(
-                            reports.codes.INVALID_OPTION_VALUE,
-                            option_name="stonith-watchdog-timeout",
-                            option_value=value,
-                            allowed_values="time interval (e.g. 1, 2s, 3m, 4h, ...)",
-                            cannot_be_empty=False,
-                            forbidden_characters=None,
-                        )
-                    ],
-                    sbd_enabled=sbd_enabled,
-                    sbd_devices=sbd_devices,
-                    valid_value=False,
-                )
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            for value in ["invalid", "10x"]:
+                with self.subTest(property=prop_name, value=value):
+                    self.assert_validate_set(
+                        [],
+                        {prop_name: value},
+                        [
+                            fixture.error(
+                                reports.codes.INVALID_OPTION_VALUE,
+                                option_name=prop_name,
+                                option_value=value,
+                                allowed_values="time interval (e.g. 1, 2s, 3m, 4h, ...)",
+                                cannot_be_empty=False,
+                                forbidden_characters=None,
+                            )
+                        ],
+                        sbd_enabled=sbd_enabled,
+                        sbd_devices=sbd_devices,
+                        valid_value=False,
+                    )
 
     def test_set_invalid_value_stonith_watchdog_timeout_sbd_enabled_without_devices(
         self,
@@ -522,95 +558,128 @@ class TestValidateSetClusterProperties(TestCase):
     def test_unset_stonith_watchdog_timeout_sbd_enabled_without_devices(
         self,
     ):
-        for value in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES:
-            with self.subTest(value=value):
-                self.assert_validate_set(
-                    ["stonith-watchdog-timeout"],
-                    {"stonith-watchdog-timeout": value},
-                    [
-                        fixture.error(
-                            reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_UNSET,
-                            force_code=reports.codes.FORCE,
-                            reason="sbd_set_up_without_devices",
-                        )
-                    ],
-                    sbd_enabled=True,
-                )
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            for value in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES:
+                with self.subTest(property=prop_name, value=value):
+                    self.assert_validate_set(
+                        [prop_name],
+                        {prop_name: value},
+                        [
+                            fixture.error(
+                                reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_UNSET,
+                                force_code=reports.codes.FORCE,
+                                reason="sbd_set_up_without_devices",
+                            )
+                        ],
+                        sbd_enabled=True,
+                    )
 
     def test_unset_stonith_watchdog_timeout_sbd_enabled_without_devices_forced(
         self,
     ):
-        for value in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES:
-            with self.subTest(value=value):
-                self.assert_validate_set(
-                    ["stonith-watchdog-timeout"],
-                    {"stonith-watchdog-timeout": value},
-                    [
-                        fixture.warn(
-                            reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_UNSET,
-                            reason="sbd_set_up_without_devices",
-                        )
-                    ],
-                    force=True,
-                    sbd_enabled=True,
-                )
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            for value in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES:
+                with self.subTest(property=prop_name, value=value):
+                    self.assert_validate_set(
+                        [prop_name],
+                        {prop_name: value},
+                        [
+                            fixture.warn(
+                                reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_UNSET,
+                                reason="sbd_set_up_without_devices",
+                            )
+                        ],
+                        force=True,
+                        sbd_enabled=True,
+                    )
 
     def test_set_stonith_watchdog_timeout_sbd_enabled_with_devices(self):
-        self.assert_validate_set(
-            [],
-            {"stonith-watchdog-timeout": "15"},
-            [
-                fixture.error(
-                    reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_SET,
-                    force_code=reports.codes.FORCE,
-                    reason="sbd_set_up_with_devices",
-                )
-            ],
-            sbd_enabled=True,
-            sbd_devices=True,
-        )
-
-    def test_set_stonith_watchdog_timeout_sbd_enabled_with_devices_forced(self):
-        self.assert_validate_set(
-            [],
-            {"stonith-watchdog-timeout": "15s"},
-            [
-                fixture.warn(
-                    reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_SET,
-                    reason="sbd_set_up_with_devices",
-                )
-            ],
-            sbd_enabled=True,
-            sbd_devices=True,
-            force=True,
-        )
-
-    def test_unset_stonith_watchdog_timeout_sbd_enabled_with_devices(self):
-        for value in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES:
-            with self.subTest(value=value):
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            with self.subTest(property=prop_name):
                 self.assert_validate_set(
-                    ["stonith-watchdog-timeout"],
-                    {"stonith-watchdog-timeout": value},
                     [],
+                    {prop_name: "15"},
+                    [
+                        fixture.error(
+                            reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_SET,
+                            force_code=reports.codes.FORCE,
+                            reason="sbd_set_up_with_devices",
+                        )
+                    ],
                     sbd_enabled=True,
                     sbd_devices=True,
                 )
 
-    def test_remove_not_configured_stonith_watchdog_timeout(self):
-        self.assert_validate_set(
-            ["a", "b"],
-            {"stonith-watchdog-timeout": ""},
-            [
-                fixture.error(
-                    reports.codes.ADD_REMOVE_CANNOT_REMOVE_ITEMS_NOT_IN_THE_CONTAINER,
-                    force_code=reports.codes.FORCE,
-                    container_type=reports.const.ADD_REMOVE_CONTAINER_TYPE_PROPERTY_SET,
-                    item_type=reports.const.ADD_REMOVE_ITEM_TYPE_PROPERTY,
-                    container_id="property-set-id",
-                    item_list=["stonith-watchdog-timeout"],
+    def test_set_stonith_watchdog_timeout_sbd_enabled_with_devices_forced(self):
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            with self.subTest(property=prop_name):
+                self.assert_validate_set(
+                    [],
+                    {prop_name: "15s"},
+                    [
+                        fixture.warn(
+                            reports.codes.STONITH_WATCHDOG_TIMEOUT_CANNOT_BE_SET,
+                            reason="sbd_set_up_with_devices",
+                        )
+                    ],
+                    sbd_enabled=True,
+                    sbd_devices=True,
+                    force=True,
                 )
-            ],
-        )
+
+    def test_unset_stonith_watchdog_timeout_sbd_enabled_with_devices(self):
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            for value in STONITH_WATCHDOG_TIMEOUT_UNSET_VALUES:
+                with self.subTest(property=prop_name, value=value):
+                    self.assert_validate_set(
+                        [prop_name],
+                        {prop_name: value},
+                        [],
+                        sbd_enabled=True,
+                        sbd_devices=True,
+                    )
+
+    def test_remove_not_configured_stonith_watchdog_timeout(self):
+        for prop_name in STONITH_WATCHDOG_TIMEOUT_PROPERTIES:
+            with self.subTest(property=prop_name):
+                self.assert_validate_set(
+                    ["a", "b"],
+                    {prop_name: ""},
+                    [
+                        fixture.error(
+                            reports.codes.ADD_REMOVE_CANNOT_REMOVE_ITEMS_NOT_IN_THE_CONTAINER,
+                            force_code=reports.codes.FORCE,
+                            container_type=reports.const.ADD_REMOVE_CONTAINER_TYPE_PROPERTY_SET,
+                            item_type=reports.const.ADD_REMOVE_ITEM_TYPE_PROPERTY,
+                            container_id="property-set-id",
+                            item_list=[prop_name],
+                        )
+                    ],
+                )
+
+    def test_warn_about_disable_fencing(self):
+        code = reports.codes.NO_STONITH_MEANS_WOULD_BE_LEFT_DUE_TO_PROPERTIES
+
+        def assert_no_fencing_warning(property_map):
+            self.assert_validate_set(
+                [],
+                property_map,
+                [fixture.warn(code, property_map=property_map)],
+            )
+
+        for falsy_value in packemaker_values._BOOLEAN_FALSE:
+            with self.subTest(value=falsy_value):
+                assert_no_fencing_warning(
+                    {
+                        "stonith-enabled": falsy_value,
+                        "fencing-enabled": falsy_value,
+                    }
+                )
+            with self.subTest(value=falsy_value):
+                assert_no_fencing_warning({"stonith-enabled": falsy_value})
+
+            with self.subTest(value=falsy_value):
+                assert_no_fencing_warning({"fencing-enabled": falsy_value})
 
     def test_remove_valid_configured_options(self):
         self.assert_validate_set(
@@ -701,7 +770,7 @@ class TestValidateSetClusterProperties(TestCase):
     def test_remove_forbidden_options(self):
         self.assert_validate_set(
             FORBIDDEN_OPTIONS_LIST,
-            {key: "" for key in FORBIDDEN_OPTIONS_LIST},
+            dict.fromkeys(FORBIDDEN_OPTIONS_LIST, ""),
             [
                 fixture.error(
                     reports.codes.INVALID_OPTIONS,
@@ -716,7 +785,7 @@ class TestValidateSetClusterProperties(TestCase):
     def test_remove_forbidden_options_forced(self):
         self.assert_validate_set(
             FORBIDDEN_OPTIONS_LIST,
-            {key: "" for key in FORBIDDEN_OPTIONS_LIST},
+            dict.fromkeys(FORBIDDEN_OPTIONS_LIST, ""),
             [
                 fixture.error(
                     reports.codes.INVALID_OPTIONS,
