@@ -255,7 +255,7 @@ class CorosyncOption(TestCase):
         bad_names = [f"na{char}me" for char in ".: {}#č"]
         assert_report_item_list_equal(
             validate.CorosyncOption().validate(
-                {name: "value" for name in bad_names}
+                dict.fromkeys(bad_names, "value")
             ),
             [
                 fixture.error(
@@ -271,7 +271,7 @@ class CorosyncOption(TestCase):
         bad_names = [f"na{char}me" for char in ".: {}#č"]
         assert_report_item_list_equal(
             validate.CorosyncOption(option_type="type").validate(
-                {name: "value" for name in bad_names}
+                dict.fromkeys(bad_names, "value")
             ),
             [
                 fixture.error(
@@ -677,6 +677,31 @@ class NamesIn(TestCase):
         )
 
 
+class PcmkMetaAttributeNamesIn(TestCase):
+    def test_return_empty_report_on_known_meta(self):
+        assert_report_item_list_equal(
+            validate.PcmkMetaAttributeNamesIn(
+                ["a", "b", "c"], ["type1", "type2"]
+            ).validate({"a": "A", "b": "B"}),
+            [],
+        )
+
+    def test_return_warning_on_unknown_meta(self):
+        assert_report_item_list_equal(
+            validate.PcmkMetaAttributeNamesIn(
+                ["a", "b", "c"], ["type2", "type1"]
+            ).validate({"c": "C", "d": "", "e": "E"}),
+            [
+                fixture.warn(
+                    reports.codes.META_ATTRS_UNKNOWN_TO_PCMK,
+                    unknown_meta=["d", "e"],
+                    known_meta=["a", "b", "c"],
+                    meta_types=["type1", "type2"],
+                ),
+            ],
+        )
+
+
 ### values validators
 
 
@@ -1257,11 +1282,25 @@ class ValueInteger(TestCase):
     def fixture_validator(self):
         return validate.ValueInteger("key")
 
+    def fixture_validator_bounds(self):
+        return validate.ValueInteger("key", -5, 5)
+
+    def fixture_validator_at_least(self):
+        return validate.ValueInteger("key", -5, None)
+
+    def fixture_validator_at_most(self):
+        return validate.ValueInteger("key", None, 5)
+
     def test_empty_report_on_valid_option(self):
         assert_report_item_list_equal(
             self.fixture_validator().validate({"key": "2"}), []
         )
 
+    def test_empty_report_on_valid_option_bounds(self):
+        assert_report_item_list_equal(
+            self.fixture_validator_bounds().validate({"key": "2"}), []
+        )
+
     def test_report_invalid_value(self):
         assert_report_item_list_equal(
             self.fixture_validator().validate({"key": "6a"}),
@@ -1277,21 +1316,9 @@ class ValueInteger(TestCase):
             ],
         )
 
-
-class ValueIntegerInRange(TestCase):
-    # The real code only calls ValuePredicateBase and is_integer which are both
-    # heavily tested on their own => only basic tests here.
-    def fixture_validator(self):
-        return validate.ValueIntegerInRange("key", -5, 5)
-
-    def test_empty_report_on_valid_option(self):
+    def test_report_invalid_value_bounds(self):
         assert_report_item_list_equal(
-            self.fixture_validator().validate({"key": "2"}), []
-        )
-
-    def test_report_invalid_value(self):
-        assert_report_item_list_equal(
-            self.fixture_validator().validate({"key": "6"}),
+            self.fixture_validator_bounds().validate({"key": "6"}),
             [
                 fixture.error(
                     reports.codes.INVALID_OPTION_VALUE,
@@ -1304,6 +1331,36 @@ class ValueIntegerInRange(TestCase):
             ],
         )
 
+    def test_report_invalid_value_at_least(self):
+        assert_report_item_list_equal(
+            self.fixture_validator_at_least().validate({"key": "-6"}),
+            [
+                fixture.error(
+                    reports.codes.INVALID_OPTION_VALUE,
+                    option_name="key",
+                    option_value="-6",
+                    allowed_values="an integer greater than or equal to -5",
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+            ],
+        )
+
+    def test_report_invalid_value_at_most(self):
+        assert_report_item_list_equal(
+            self.fixture_validator_at_most().validate({"key": "6"}),
+            [
+                fixture.error(
+                    reports.codes.INVALID_OPTION_VALUE,
+                    option_name="key",
+                    option_value="6",
+                    allowed_values="an integer smaller than or equal to 5",
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+            ],
+        )
+
 
 class ValueIpAddress(TestCase):
     # The real code only calls ValuePredicateBase and is_ipv4_address and
@@ -1393,6 +1450,84 @@ class ValueNotEmpty(TestCase):
         )
 
 
+class ValueStringLength(TestCase):
+    # The real code only calls ValuePredicateBase => only basic tests here.
+    def test_empty_report_on_valid_value(self):
+        for value in [
+            "aa",
+            "a" * 5,
+            "a" * 10,
+        ]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValueStringLength("key", 2, 10).validate(
+                        {"key": value}
+                    ),
+                    [],
+                )
+
+    def test_empty_report_no_min_len(self):
+        for value in ["", "aaa"]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValueStringLength("key", None, 10).validate(
+                        {"key": value}
+                    ),
+                    [],
+                )
+
+    def test_report_invalid_value_min_max(self):
+        for value in ["a", "aaaa"]:
+            with self.subTest(value=value):
+                assert_report_item_list_equal(
+                    validate.ValueStringLength("key", 2, 3).validate(
+                        {"key": value}
+                    ),
+                    [
+                        fixture.error(
+                            reports.codes.INVALID_OPTION_VALUE,
+                            option_name="key",
+                            option_value=value,
+                            allowed_values="a string (min length: 2) (max length: 3)",
+                            cannot_be_empty=True,
+                            forbidden_characters=None,
+                        ),
+                    ],
+                )
+
+    def test_report_invalid_value_only_min(self):
+        assert_report_item_list_equal(
+            validate.ValueStringLength("key", min_len=2).validate({"key": "a"}),
+            [
+                fixture.error(
+                    reports.codes.INVALID_OPTION_VALUE,
+                    option_name="key",
+                    option_value="a",
+                    allowed_values="a string (min length: 2)",
+                    cannot_be_empty=True,
+                    forbidden_characters=None,
+                ),
+            ],
+        )
+
+    def test_report_invalid_value_only_max(self):
+        assert_report_item_list_equal(
+            validate.ValueStringLength("key", max_len=2).validate(
+                {"key": "aaa"}
+            ),
+            [
+                fixture.error(
+                    reports.codes.INVALID_OPTION_VALUE,
+                    option_name="key",
+                    option_value="aaa",
+                    allowed_values="a string (max length: 2)",
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+            ],
+        )
+
+
 class ValuePcmkBoolean(TestCase):
     # The real code only calls ValuePredicateBase => only basic tests here.
     def test_empty_report_on_valid_option(self):
