@@ -2,6 +2,9 @@ from unittest import TestCase
 
 from lxml import etree
 
+from pcs_test.tier1.cib_resource.common import (
+    fixture_meta_attributes_not_validated_warning,
+)
 from pcs_test.tools.bin_mock import get_mock_settings
 from pcs_test.tools.cib import get_assert_pcs_effect_mixin
 from pcs_test.tools.misc import get_test_resource as rc
@@ -500,6 +503,7 @@ class Clone(
                 "Deprecation Warning: configuring meta attributes without "
                 "specifying the 'meta' keyword is deprecated and will be "
                 "removed in a future release\n"
+                + fixture_meta_attributes_not_validated_warning(["clone"])
             ),
         )
 
