@@ -7,8 +7,13 @@ from pcs import resource
 from pcs.cli.common.parse_args import InputModifiers
 from pcs.common import const
 from pcs.common.str_tools import format_list
+from pcs.lib.resource_agent import const as ra_const
 
-from pcs_test.tier1.cib_resource.common import ResourceTest
+from pcs_test.tier1.cib_resource.common import (
+    ResourceTest,
+    fixture_meta_attributes_not_validated_warning,
+    fixture_meta_attributes_warning,
+)
 from pcs_test.tools.assertions import AssertPcsMixin
 from pcs_test.tools.bin_mock import get_mock_settings
 from pcs_test.tools.pcs_runner import PcsRunner
@@ -259,7 +264,8 @@ class Success(ResourceTest):
                     </meta_attributes>
                 </clone>
             </resources>""",
-            stderr_full=self.msg_clone_without_meta,
+            stderr_full=self.msg_clone_without_meta
+            + fixture_meta_attributes_not_validated_warning(["clone"]),
         )
 
     def test_create_with_options_and_meta(self):
@@ -292,6 +298,30 @@ class Success(ResourceTest):
             </resources>""",
         )
 
+    def test_create_with_unknown_meta(self):
+        self.assert_effect(
+            (
+                "resource create R ocf:pcsmock:minimal --no-default-ops meta "
+                "unknown_meta=unknown_value"
+            ).split(),
+            """<resources>
+                <primitive class="ocf" id="R" provider="pcsmock" type="minimal">
+                    <meta_attributes id="R-meta_attributes">
+                        <nvpair id="R-meta_attributes-unknown_meta"
+                            name="unknown_meta" value="unknown_value"></nvpair>
+                    </meta_attributes>
+                    <operations>
+                        <op id="R-monitor-interval-10s" interval="10s"
+                            name="monitor" timeout="20s"
+                        />
+                    </operations>
+                </primitive>
+            </resources>""",
+            stderr_full=fixture_meta_attributes_warning(
+                ["unknown_meta"], ra_const.PRIMITIVE_META
+            ),
+        )
+
 
 class SuccessOperations(ResourceTest):
     def setUp(self):
@@ -581,6 +611,9 @@ class SuccessNewParser(ResourceTest):
                     </operations>
                 </primitive>
             </resources>""",
+            stderr_full=fixture_meta_attributes_warning(
+                ["a"], ra_const.PRIMITIVE_META
+            ),
         )
 
     def test_clone_meta(self):
@@ -600,6 +633,9 @@ class SuccessNewParser(ResourceTest):
                     </meta_attributes>
                 </clone>
             </resources>""",
+            stderr_full=fixture_meta_attributes_not_validated_warning(
+                ["clone"]
+            ),
         )
 
     def test_primitive_and_clone_meta(self):
@@ -622,6 +658,8 @@ class SuccessNewParser(ResourceTest):
                     </meta_attributes>
                 </clone>
             </resources>""",
+            stderr_full=fixture_meta_attributes_not_validated_warning(["clone"])
+            + fixture_meta_attributes_warning(["a"], ra_const.PRIMITIVE_META),
         )
 
 
@@ -1178,7 +1216,7 @@ class FailOrWarn(ResourceTest):
             ),
         )
 
-    def test_warn_when_forcing_noexistent_agent(self):
+    def test_warn_when_forcing_nonexistent_agent(self):
         self.assert_effect(
             "resource create R ocf:heartbeat:NoExisting --force".split(),
             """<resources>
@@ -1623,6 +1661,9 @@ class FailOrWarnGroup(ResourceTest):
                     </operations>
                 </primitive>
             </resources>""",
+            stderr_full=fixture_meta_attributes_warning(
+                ["a"], ra_const.PRIMITIVE_META
+            ),
         )
         self.assert_pcs_fail(
             (
