@@ -1,28 +1,15 @@
-from unittest import (
-    TestCase,
-    mock,
-)
+from unittest import TestCase
 
 from lxml import etree
 
-from pcs import (
-    node,
-    utils,
-)
+from pcs import utils
 
 from pcs_test.tier1.legacy.common import FIXTURE_UTILIZATION_WARNING
 from pcs_test.tools.assertions import AssertPcsMixin
 from pcs_test.tools.cib import get_assert_pcs_effect_mixin
 from pcs_test.tools.misc import get_test_resource as rc
-from pcs_test.tools.misc import (
-    get_tmp_file,
-    outdent,
-    write_file_to_tmpfile,
-)
-from pcs_test.tools.pcs_runner import (
-    PcsRunner,
-    pcs,
-)
+from pcs_test.tools.misc import get_tmp_file, outdent, write_file_to_tmpfile
+from pcs_test.tools.pcs_runner import PcsRunner, pcs
 
 empty_cib = rc("cib-empty-withnodes.xml")
 
@@ -90,14 +77,7 @@ class NodeUtilizationSet(
         stdout, stderr, retval = pcs(
             self.temp_cib.name, "node utilization rh7-2".split()
         )
-        self.assertEqual(
-            stdout,
-            outdent(
-                """\
-                Node Utilization:
-                """
-            ),
-        )
+        self.assertEqual(stdout, "")
         self.assertEqual(stderr, FIXTURE_UTILIZATION_WARNING)
         self.assertEqual(retval, 0)
 
@@ -108,8 +88,9 @@ class NodeUtilizationSet(
             stdout,
             outdent(
                 """\
-                Node Utilization:
-                 rh7-1: test1=10
+                Node: rh7-1
+                  Utilization: nodes-1-utilization
+                    test1=10
                 """
             ),
         )
@@ -131,8 +112,10 @@ class NodeUtilizationSet(
             stdout,
             outdent(
                 """\
-                Node Utilization:
-                 rh7-1: test1=-10 test4=1234
+                Node: rh7-1
+                  Utilization: nodes-1-utilization
+                    test1=-10
+                    test4=1234
                 """
             ),
         )
@@ -155,8 +138,9 @@ class NodeUtilizationSet(
             stdout,
             outdent(
                 """\
-                Node Utilization:
-                 rh7-2: test2=321
+                Node: rh7-2
+                  Utilization: nodes-2-utilization
+                    test2=321
                 """
             ),
         )
@@ -170,9 +154,13 @@ class NodeUtilizationSet(
             stdout,
             outdent(
                 """\
-                Node Utilization:
-                 rh7-1: test1=-10 test4=1234
-                 rh7-2: test2=321
+                Node: rh7-1
+                  Utilization: nodes-1-utilization
+                    test1=-10
+                    test4=1234
+                Node: rh7-2
+                  Utilization: nodes-2-utilization
+                    test2=321
                 """
             ),
         )
@@ -193,9 +181,12 @@ class NodeUtilizationSet(
             stdout,
             outdent(
                 """\
-                Node Utilization:
-                 rh7-1: test1=-10
-                 rh7-2: test1=-20
+                Node: rh7-1
+                  Utilization: nodes-1-utilization
+                    test1=-10
+                Node: rh7-2
+                  Utilization: nodes-2-utilization
+                    test1=-20
                 """
             ),
         )
@@ -210,8 +201,9 @@ class NodeUtilizationSet(
             stdout,
             outdent(
                 """\
-                Node Utilization:
-                 rh7-2: test1=-20
+                Node: rh7-2
+                  Utilization: nodes-2-utilization
+                    test1=-20
                 """
             ),
         )
@@ -295,42 +287,7 @@ class NodeUtilizationSet(
             self.fixture_xml_no_utilization(),
         )
         self.assert_effect(
-            "node utilization".split(),
-            self.fixture_xml_no_utilization(),
-            stdout_full="Node Utilization:\n",
-        )
-
-
-class NodeUtilizationPrint(TestCase, AssertPcsMixin):
-    def setUp(self):
-        self.temp_cib = get_tmp_file("tier1_node_utilization_print")
-        write_file_to_tmpfile(empty_cib, self.temp_cib)
-        self.pcs_runner = PcsRunner(self.temp_cib.name)
-
-    def tearDown(self):
-        self.temp_cib.close()
-
-    @mock.patch("pcs.node.utils")
-    def test_refuse_when_node_not_in_cib_and_is_not_remote(self, mock_utils):
-        mock_cib = mock.MagicMock()
-        mock_cib.getElementsByTagName = mock.Mock(return_value=[])
-
-        mock_utils.get_cib_dom = mock.Mock(return_value=mock_cib)
-        mock_utils.usefile = False
-        mock_utils.getNodeAttributesFromPacemaker = mock.Mock(return_value=[])
-        mock_utils.err = mock.Mock(side_effect=SystemExit)
-
-        self.assertRaises(
-            SystemExit, lambda: node.print_node_utilization("some")
-        )
-
-    def test_refuse_when_node_not_in_mocked_cib(self):
-        self.assert_pcs_fail(
-            "node utilization some_nonexistent_node".split(),
-            (
-                f"{FIXTURE_UTILIZATION_WARNING}"
-                "Error: Unable to find a node: some_nonexistent_node\n"
-            ),
+            "node utilization".split(), self.fixture_xml_no_utilization()
         )
 
 
@@ -348,17 +305,22 @@ class NodeStandby(TestCase, AssertPcsMixin):
         self.assert_standby_all()
 
     def assert_standby_none(self):
-        self.assert_pcs_success("node attribute".split(), "Node Attributes:\n")
+        self.assert_pcs_success("node attribute".split())
 
     def assert_standby_all(self):
         self.assert_pcs_success(
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-1: standby=on
-                 rh7-2: standby=on
-                 rh7-3: standby=on
+                Node: rh7-1
+                  Attributes: nodes-1
+                    standby=on
+                Node: rh7-2
+                  Attributes: nodes-2
+                    standby=on
+                Node: rh7-3
+                  Attributes: nodes-3
+                    standby=on
                 """
             ),
         )
@@ -425,8 +387,9 @@ class NodeStandby(TestCase, AssertPcsMixin):
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-1: standby=on
+                Node: rh7-1
+                  Attributes: nodes-1
+                    standby=on
                 """
             ),
         )
@@ -438,9 +401,12 @@ class NodeStandby(TestCase, AssertPcsMixin):
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-2: standby=on
-                 rh7-3: standby=on
+                Node: rh7-2
+                  Attributes: nodes-2
+                    standby=on
+                Node: rh7-3
+                  Attributes: nodes-3
+                    standby=on
                 """
             ),
         )
@@ -453,9 +419,12 @@ class NodeStandby(TestCase, AssertPcsMixin):
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-1: standby=on
-                 rh7-2: standby=on
+                Node: rh7-1
+                  Attributes: nodes-1
+                    standby=on
+                Node: rh7-2
+                  Attributes: nodes-2
+                    standby=on
                 """
             ),
         )
@@ -466,8 +435,9 @@ class NodeStandby(TestCase, AssertPcsMixin):
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-3: standby=on
+                Node: rh7-3
+                  Attributes: nodes-3
+                    standby=on
                 """
             ),
         )
@@ -497,17 +467,22 @@ class NodeMaintenance(TestCase, AssertPcsMixin):
         self.assert_maintenance_all()
 
     def assert_maintenance_none(self):
-        self.assert_pcs_success("node attribute".split(), "Node Attributes:\n")
+        self.assert_pcs_success("node attribute".split())
 
     def assert_maintenance_all(self):
         self.assert_pcs_success(
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-1: maintenance=on
-                 rh7-2: maintenance=on
-                 rh7-3: maintenance=on
+                Node: rh7-1
+                  Attributes: nodes-1
+                    maintenance=on
+                Node: rh7-2
+                  Attributes: nodes-2
+                    maintenance=on
+                Node: rh7-3
+                  Attributes: nodes-3
+                    maintenance=on
                 """
             ),
         )
@@ -574,8 +549,9 @@ class NodeMaintenance(TestCase, AssertPcsMixin):
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-1: maintenance=on
+                Node: rh7-1
+                  Attributes: nodes-1
+                    maintenance=on
                 """
             ),
         )
@@ -587,9 +563,12 @@ class NodeMaintenance(TestCase, AssertPcsMixin):
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-2: maintenance=on
-                 rh7-3: maintenance=on
+                Node: rh7-2
+                  Attributes: nodes-2
+                    maintenance=on
+                Node: rh7-3
+                  Attributes: nodes-3
+                    maintenance=on
                 """
             ),
         )
@@ -602,9 +581,12 @@ class NodeMaintenance(TestCase, AssertPcsMixin):
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-1: maintenance=on
-                 rh7-2: maintenance=on
+                Node: rh7-1
+                  Attributes: nodes-1
+                    maintenance=on
+                Node: rh7-2
+                  Attributes: nodes-2
+                    maintenance=on
                 """
             ),
         )
@@ -615,8 +597,9 @@ class NodeMaintenance(TestCase, AssertPcsMixin):
             "node attribute".split(),
             outdent(
                 """\
-                Node Attributes:
-                 rh7-3: maintenance=on
+                Node: rh7-3
+                  Attributes: nodes-3
+                    maintenance=on
                 """
             ),
         )
@@ -714,7 +697,7 @@ class NodeAttributeTest(
 
     def test_show_empty(self):
         self.fixture_attrs(["rh7-1", "rh7-2"])
-        self.assert_pcs_success("node attribute".split(), "Node Attributes:\n")
+        self.assert_pcs_success("node attribute".split())
 
     def test_show_nonempty(self):
         self.fixture_attrs(
@@ -730,11 +713,16 @@ class NodeAttributeTest(
         )
         self.assert_pcs_success(
             "node attribute".split(),
-            """\
-Node Attributes:
- rh7-1: IP=192.168.1.1
- rh7-2: IP=192.168.1.2
-""",
+            outdent(
+                """\
+                Node: rh7-1
+                  Attributes: nodes-1
+                    IP=192.168.1.1
+                Node: rh7-2
+                  Attributes: nodes-2
+                    IP=192.168.1.2
+                """
+            ),
         )
 
     def test_show_multiple_per_node(self):
@@ -753,11 +741,18 @@ Node Attributes:
         )
         self.assert_pcs_success(
             "node attribute".split(),
-            """\
-Node Attributes:
- rh7-1: IP=192.168.1.1 alias=node1
- rh7-2: IP=192.168.1.2 alias=node2
-""",
+            outdent(
+                """\
+                Node: rh7-1
+                  Attributes: nodes-1
+                    IP=192.168.1.1
+                    alias=node1
+                Node: rh7-2
+                  Attributes: nodes-2
+                    IP=192.168.1.2
+                    alias=node2
+                """
+            ),
         )
 
     def test_show_one_node(self):
@@ -776,10 +771,14 @@ Node Attributes:
         )
         self.assert_pcs_success(
             "node attribute rh7-1".split(),
-            """\
-Node Attributes:
- rh7-1: IP=192.168.1.1 alias=node1
-""",
+            outdent(
+                """\
+                Node: rh7-1
+                  Attributes: nodes-1
+                    IP=192.168.1.1
+                    alias=node1
+                """
+            ),
         )
 
     def test_show_missing_node(self):
@@ -796,11 +795,9 @@ Node Attributes:
                 },
             },
         )
-        self.assert_pcs_success(
+        self.assert_pcs_fail(
             "node attribute rh7-3".split(),
-            """\
-Node Attributes:
-""",
+            "Error: Unable to find a node: rh7-3\n",
         )
 
     def test_show_name(self):
@@ -819,11 +816,16 @@ Node Attributes:
         )
         self.assert_pcs_success(
             "node attribute --name alias".split(),
-            """\
-Node Attributes:
- rh7-1: alias=node1
- rh7-2: alias=node2
-""",
+            outdent(
+                """\
+                Node: rh7-1
+                  Attributes: nodes-1
+                    alias=node1
+                Node: rh7-2
+                  Attributes: nodes-2
+                    alias=node2
+                """
+            ),
         )
 
     def test_show_missing_name(self):
@@ -840,12 +842,7 @@ Node Attributes:
                 },
             },
         )
-        self.assert_pcs_success(
-            "node attribute --name missing".split(),
-            """\
-Node Attributes:
-""",
-        )
+        self.assert_pcs_success("node attribute --name missing".split())
 
     def test_show_node_and_name(self):
         self.fixture_attrs(
@@ -863,10 +860,13 @@ Node Attributes:
         )
         self.assert_pcs_success(
             "node attribute --name alias rh7-1".split(),
-            """\
-Node Attributes:
- rh7-1: alias=node1
-""",
+            outdent(
+                """\
+                Node: rh7-1
+                  Attributes: nodes-1
+                    alias=node1
+                """
+            ),
         )
 
     def test_set_new(self):
@@ -874,19 +874,27 @@ Node Attributes:
         self.assert_pcs_success("node attribute rh7-1 IP=192.168.1.1".split())
         self.assert_pcs_success(
             "node attribute".split(),
-            """\
-Node Attributes:
- rh7-1: IP=192.168.1.1
-""",
+            outdent(
+                """\
+                Node: rh7-1
+                  Attributes: nodes-1
+                    IP=192.168.1.1
+                """
+            ),
         )
         self.assert_pcs_success("node attribute rh7-2 IP=192.168.1.2".split())
         self.assert_pcs_success(
             "node attribute".split(),
-            """\
-Node Attributes:
- rh7-1: IP=192.168.1.1
- rh7-2: IP=192.168.1.2
-""",
+            outdent(
+                """\
+                Node: rh7-1
+                  Attributes: nodes-1
+                    IP=192.168.1.1
+                Node: rh7-2
+                  Attributes: nodes-2
+                    IP=192.168.1.2
+                """
+            ),
         )
 
     def test_set_existing(self):
@@ -904,11 +912,16 @@ Node Attributes:
         self.assert_pcs_success("node attribute rh7-2 IP=192.168.2.2".split())
         self.assert_pcs_success(
             "node attribute".split(),
-            """\
-Node Attributes:
- rh7-1: IP=192.168.1.1
- rh7-2: IP=192.168.2.2
-""",
+            outdent(
+                """\
+                Node: rh7-1
+                  Attributes: nodes-1
+                    IP=192.168.1.1
+                Node: rh7-2
+                  Attributes: nodes-2
+                    IP=192.168.2.2
+                """
+            ),
         )
 
     def test_unset(self):
@@ -926,10 +939,13 @@ Node Attributes:
         self.assert_pcs_success("node attribute rh7-2 IP=".split())
         self.assert_pcs_success(
             "node attribute".split(),
-            """\
-Node Attributes:
- rh7-1: IP=192.168.1.1
-""",
+            outdent(
+                """\
+                Node: rh7-1
+                  Attributes: nodes-1
+                    IP=192.168.1.1
+                """
+            ),
         )
 
     def test_unset_nonexisting(self):
