@@ -7,17 +7,14 @@ from lxml import etree
 
 from pcs.common.interface.dto import to_dict
 from pcs.common.pacemaker.defaults import CibDefaultsDto
-from pcs.common.pacemaker.nvset import (
-    CibNvpairDto,
-    CibNvsetDto,
-)
+from pcs.common.pacemaker.nvset import CibNvpairDto, CibNvsetDto
 from pcs.common.pacemaker.rule import CibRuleExpressionDto
-from pcs.common.types import (
-    CibRuleExpressionType,
-    CibRuleInEffectStatus,
-)
+from pcs.common.str_tools import format_list, format_plural
+from pcs.common.types import CibRuleExpressionType, CibRuleInEffectStatus
 
+from pcs_test.tools import metadata_dto
 from pcs_test.tools.assertions import AssertPcsMixin
+from pcs_test.tools.bin_mock import get_mock_settings
 from pcs_test.tools.cib import get_assert_pcs_effect_mixin
 from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
@@ -43,6 +40,28 @@ DEFAULTS_MAY_BE_OVERRIDDEN = (
     "with their own defined values\n"
 )
 CIB_HAS_BEEN_UPGRADED = "CIB has been upgraded to the latest schema version.\n"
+META_NOT_VALIDATED = (
+    "Warning: Meta attributes of bundle / clone / group / resource are not "
+    "validated\n"
+)
+
+
+def fixture_warning_unknown_meta_primitive(unknown_meta):
+    known_meta = format_list(
+        sorted(
+            set(
+                metadata_dto.FIXTURE_KNOWN_META_NAMES_PRIMITIVE_META
+                + metadata_dto.FIXTURE_KNOWN_META_NAMES_STONITH_META
+            )
+        )
+    )
+    attributes = format_plural(unknown_meta, "attribute")
+    have = format_plural(unknown_meta, "has")
+    return (
+        f"Warning: Resource / stonith meta {attributes} "
+        f"{format_list(unknown_meta)} {have} no effect on cluster resource "
+        f"handling, meta attributes with effect: {known_meta}\n"
+    )
 
 
 def fixture_defaults_dto(prefix, include_expired):
@@ -161,6 +180,7 @@ class TestDefaultsMixin:
     def setUp(self):
         self.temp_cib = get_tmp_file("tier1_cib_options")
         self.pcs_runner = PcsRunner(self.temp_cib.name)
+        self.pcs_runner.mock_settings = get_mock_settings("crm_resource_exec")
         self.maxDiff = None
 
     def tearDown(self):
@@ -272,8 +292,8 @@ class DefaultsConfigMixin(TestDefaultsMixin, AssertPcsMixin):
                         />
                     </rule>
                 </rule>
-                <nvpair id="{tag}-set1-nam1" name="nam1" value="val1"/>
-                <nvpair id="{tag}-set1-nam2" name="nam2" value="val2"/>
+                <nvpair id="{tag}-set1-name1" name="name1" value="value1"/>
+                <nvpair id="{tag}-set1-name2" name="name2" value="value2"/>
             </meta_attributes>
         </{tag}_defaults>"""
         self._prepare_cib_data(xml_template, empty_cib_rules)
@@ -283,8 +303,8 @@ class DefaultsConfigMixin(TestDefaultsMixin, AssertPcsMixin):
             stdout_full=dedent(
                 f"""\
                 Meta Attrs: {self.prefix}-set1
-                  nam1=val1
-                  nam2=val2
+                  name1=value1
+                  name2=value2
                   Rule: boolean-op=and
                     Rule: boolean-op=or
                       Expression: defined attr1
@@ -491,7 +511,7 @@ class RscDefaultsConfig(
                     <rule id="X-rule" boolean-op="and">
                         <rsc_expression id="X-rule-rsc-Dummy" type="Dummy"/>
                     </rule>
-                    <nvpair id="X-nam1" name="nam1" value="val1"/>
+                    <nvpair id="X-name1" name="name1" value="value1"/>
                 </meta_attributes>
             </rsc_defaults>
         """
@@ -504,7 +524,7 @@ class RscDefaultsConfig(
             stdout_full=dedent(
                 """\
                 Meta Attrs: X
-                  nam1=val1
+                  name1=value1
                   Rule: boolean-op=and
                     Expression: resource ::Dummy
             """
@@ -528,7 +548,7 @@ class OpDefaultsConfig(
                         <rsc_expression id="X-rule-rsc-Dummy" type="Dummy"/>
                         <op_expression id="X-rule-op-monitor" name="monitor"/>
                     </rule>
-                    <nvpair id="X-nam1" name="nam1" value="val1"/>
+                    <nvpair id="X-name1" name="name1" value="value1"/>
                 </meta_attributes>
             </op_defaults>
         """
@@ -541,7 +561,7 @@ class OpDefaultsConfig(
             stdout_full=dedent(
                 """\
                 Meta Attrs: X
-                  nam1=val1
+                  name1=value1
                   Rule: boolean-op=and
                     Expression: resource ::Dummy
                     Expression: op monitor
@@ -553,6 +573,7 @@ class OpDefaultsConfig(
 class DefaultsSetCreateMixin(TestDefaultsMixin, AssertPcsMixin):
     cli_command = []
     cib_tag = ""
+    meta_warning_not_validated = ""
 
     def setUp(self):
         super().setUp()
@@ -574,24 +595,26 @@ class DefaultsSetCreateMixin(TestDefaultsMixin, AssertPcsMixin):
     def test_success(self):
         self.assert_effect(
             self.cli_command
-            + "set create id=mine score=10 meta nam1=val1 nam2=val2 --force".split(),
+            + "set create id=mine score=10 meta name1=value1 name2=value2 --force".split(),
             dedent(
                 f"""\
                 <{self.cib_tag}>
                     <meta_attributes id="mine" score="10">
-                        <nvpair id="mine-nam1" name="nam1" value="val1"/>
-                        <nvpair id="mine-nam2" name="nam2" value="val2"/>
+                        <nvpair id="mine-name1" name="name1" value="value1"/>
+                        <nvpair id="mine-name2" name="name2" value="value2"/>
                     </meta_attributes>
                 </{self.cib_tag}>
             """
             ),
-            stderr_full=DEFAULTS_MAY_BE_OVERRIDDEN,
+            stderr_full=(
+                self.meta_warning_not_validated + DEFAULTS_MAY_BE_OVERRIDDEN
+            ),
         )
 
     def _assert_success_rule(self, deprecated_rule_form):
         command = (
             self.cli_command
-            + "-- set create id=mine score=10 meta nam1=val1 nam2=val2 rule".split()
+            + "-- set create id=mine score=10 meta name1=value1 name2=value2 rule".split()
         )
         rule_str = (
             "(date gt 2018-05-17T13:28:19 or "
@@ -638,8 +661,8 @@ class DefaultsSetCreateMixin(TestDefaultsMixin, AssertPcsMixin):
                                   operation="in_range" end="2019-12-15"
                             />
                         </rule>
-                        <nvpair id="mine-nam1" name="nam1" value="val1"/>
-                        <nvpair id="mine-nam2" name="nam2" value="val2"/>
+                        <nvpair id="mine-name1" name="name1" value="value1"/>
+                        <nvpair id="mine-name2" name="name2" value="value2"/>
                     </meta_attributes>
                 </{self.cib_tag}>
             """
@@ -647,6 +670,7 @@ class DefaultsSetCreateMixin(TestDefaultsMixin, AssertPcsMixin):
             stderr_full=(
                 (RULE_ARGV_DEPRECATED if deprecated_rule_form else "")
                 + CIB_HAS_BEEN_UPGRADED
+                + self.meta_warning_not_validated
                 + DEFAULTS_MAY_BE_OVERRIDDEN
             ),
         )
@@ -660,7 +684,7 @@ class DefaultsSetCreateMixin(TestDefaultsMixin, AssertPcsMixin):
     def test_rule_error_messages(self):
         self.assert_pcs_fail(
             self.cli_command
-            + "set create id=mine score=10 meta nam1=val1 nam2=val2 rule".split()
+            + "set create id=mine score=10 meta name1=value1 name2=value2 rule".split()
             + [
                 "(date gt 2018-05-1X or "
                 "date in_range 2019-03-05 to 2019-01-11 or "
@@ -685,6 +709,7 @@ class DefaultsSetCreateMixin(TestDefaultsMixin, AssertPcsMixin):
                 "'hours', 'minutes', 'monthdays', 'months', 'seconds', "
                 "'weekdays', 'weeks', 'weekyears', 'yeardays', 'years'\n"
                 "Error: Duplicate options in a single (sub)expression: 'years'\n"
+                f"{self.meta_warning_not_validated}"
                 "Error: Errors have occurred, therefore pcs is unable to continue\n"
             ),
         )
@@ -701,6 +726,7 @@ class RscDefaultsSetCreate(
 ):
     cli_command = ["resource", "defaults"]
     cib_tag = "rsc_defaults"
+    meta_warning_not_validated = META_NOT_VALIDATED
 
     @skip_unless_pacemaker_supports_rsc_and_op_rules()
     def test_success_rules_rsc_op(self):
@@ -708,7 +734,7 @@ class RscDefaultsSetCreate(
         self.assert_effect(
             (
                 self.cli_command
-                + "set create id=X meta nam1=val1 rule".split()
+                + "set create id=X meta name1=value1 rule".split()
                 + ["resource ::Dummy"]
             ),
             f"""\
@@ -719,11 +745,15 @@ class RscDefaultsSetCreate(
                     >
                         <rsc_expression id="X-rule-rsc-Dummy" type="Dummy"/>
                     </rule>
-                    <nvpair id="X-nam1" name="nam1" value="val1"/>
+                    <nvpair id="X-name1" name="name1" value="value1"/>
                 </meta_attributes>
             </{self.cib_tag}>
             """,
-            stderr_full=(CIB_HAS_BEEN_UPGRADED + DEFAULTS_MAY_BE_OVERRIDDEN),
+            stderr_full=(
+                CIB_HAS_BEEN_UPGRADED
+                + fixture_warning_unknown_meta_primitive(["name1"])
+                + DEFAULTS_MAY_BE_OVERRIDDEN
+            ),
         )
 
     def test_node_attr_expressions(self):
@@ -775,7 +805,7 @@ class OpDefaultsSetCreate(
         score_present = not is_minimum_cib_schema_version(3, 9, 0)
         self.assert_effect(
             self.cli_command
-            + "-- set create id=X meta nam1=val1 rule".split()
+            + "-- set create id=X meta name1=value1 rule".split()
             + [
                 "resource ::Dummy and (op start or op stop) and "
                 "(defined attr1 or attr2 gte number -1.2 or "
@@ -821,7 +851,7 @@ class OpDefaultsSetCreate(
                             />
                         </rule>
                     </rule>
-                    <nvpair id="X-nam1" name="nam1" value="val1"/>
+                    <nvpair id="X-name1" name="name1" value="value1"/>
                 </meta_attributes>
             </{self.cib_tag}>
             """,
@@ -907,6 +937,7 @@ class DefaultsSetUpdateMixin(TestDefaultsMixin, AssertPcsMixin):
     cli_command = []
     prefix = ""
     cib_tag = ""
+    meta_warning_not_validated = ""
 
     def test_success(self):
         xml = f"""
@@ -935,7 +966,9 @@ class DefaultsSetUpdateMixin(TestDefaultsMixin, AssertPcsMixin):
                 </{self.cib_tag}>
             """
             ),
-            stderr_full=DEFAULTS_MAY_BE_OVERRIDDEN,
+            stderr_full=(
+                self.meta_warning_not_validated + DEFAULTS_MAY_BE_OVERRIDDEN
+            ),
         )
 
         self.assert_effect(
@@ -947,7 +980,9 @@ class DefaultsSetUpdateMixin(TestDefaultsMixin, AssertPcsMixin):
                 </{self.cib_tag}>
             """
             ),
-            stderr_full=DEFAULTS_MAY_BE_OVERRIDDEN,
+            stderr_full=(
+                self.meta_warning_not_validated + DEFAULTS_MAY_BE_OVERRIDDEN
+            ),
         )
 
 
@@ -963,6 +998,46 @@ class RscDefaultsSetUpdate(
     cli_command = ["resource", "defaults"]
     prefix = "rsc"
     cib_tag = "rsc_defaults"
+    meta_warning_not_validated = META_NOT_VALIDATED
+
+    @skip_unless_pacemaker_supports_rsc_and_op_rules()
+    def test_validate_meta_for_primitive(self):
+        xml = f"""
+            <{self.cib_tag}>
+                <meta_attributes id="X">
+                    <rule id="X-rule" boolean-op="and">
+                        <rsc_expression id="X-rule-rsc-Dummy" type="Dummy"/>
+                    </rule>
+                    <nvpair id="X-name1" name="name1" value="value1" />
+                    <nvpair id="X-name2" name="name2" value="value2" />
+                    <nvpair id="X-name3" name="name3" value="value3" />
+                </meta_attributes>
+            </{self.cib_tag}>
+        """
+        xml_manip = XmlManipulation.from_file(empty_cib_rules)
+        xml_manip.append_to_first_tag_name("configuration", xml)
+        write_data_to_tmpfile(str(xml_manip), self.temp_cib)
+
+        self.assert_effect(
+            self.cli_command + "set update X meta name2=value2A name3=".split(),
+            dedent(
+                f"""\
+                <{self.cib_tag}>
+                    <meta_attributes id="X">
+                        <rule id="X-rule" boolean-op="and">
+                            <rsc_expression id="X-rule-rsc-Dummy" type="Dummy"/>
+                        </rule>
+                        <nvpair id="X-name1" name="name1" value="value1" />
+                        <nvpair id="X-name2" name="name2" value="value2A" />
+                    </meta_attributes>
+                </{self.cib_tag}>
+            """
+            ),
+            stderr_full=(
+                fixture_warning_unknown_meta_primitive(["name2"])
+                + DEFAULTS_MAY_BE_OVERRIDDEN
+            ),
+        )
 
 
 class OpDefaultsSetUpdate(
@@ -1013,6 +1088,7 @@ class DefaultsUpdateMixin(TestDefaultsMixin, AssertPcsMixin):
     cli_command = []
     prefix = ""
     cib_tag = ""
+    meta_warning_not_validated = ""
 
     def test_success_legacy(self):
         write_file_to_tmpfile(empty_cib, self.temp_cib)
@@ -1039,7 +1115,9 @@ class DefaultsUpdateMixin(TestDefaultsMixin, AssertPcsMixin):
                 </{self.cib_tag}>
             """
             ),
-            stderr_full=DEFAULTS_MAY_BE_OVERRIDDEN,
+            stderr_full=(
+                DEFAULTS_MAY_BE_OVERRIDDEN + self.meta_warning_not_validated
+            ),
         )
 
         self.assert_effect(
@@ -1058,7 +1136,9 @@ class DefaultsUpdateMixin(TestDefaultsMixin, AssertPcsMixin):
                 </{self.cib_tag}>
             """
             ),
-            stderr_full=DEFAULTS_MAY_BE_OVERRIDDEN,
+            stderr_full=(
+                DEFAULTS_MAY_BE_OVERRIDDEN + self.meta_warning_not_validated
+            ),
         )
 
         self.assert_effect(
@@ -1070,7 +1150,9 @@ class DefaultsUpdateMixin(TestDefaultsMixin, AssertPcsMixin):
                 </{self.cib_tag}>
             """
             ),
-            stderr_full=DEFAULTS_MAY_BE_OVERRIDDEN,
+            stderr_full=(
+                DEFAULTS_MAY_BE_OVERRIDDEN + self.meta_warning_not_validated
+            ),
         )
 
 
@@ -1086,6 +1168,46 @@ class RscDefaultsUpdate(
     cli_command = ["resource", "defaults"]
     prefix = "rsc"
     cib_tag = "rsc_defaults"
+    meta_warning_not_validated = META_NOT_VALIDATED
+
+    @skip_unless_pacemaker_supports_rsc_and_op_rules()
+    def test_legacy_validate_meta_for_primitive(self):
+        xml = f"""
+            <{self.cib_tag}>
+                <meta_attributes id="X">
+                    <rule id="X-rule" boolean-op="and">
+                        <rsc_expression id="X-rule-rsc-Dummy" type="Dummy"/>
+                    </rule>
+                    <nvpair id="X-name1" name="name1" value="value1" />
+                    <nvpair id="X-name2" name="name2" value="value2" />
+                    <nvpair id="X-name3" name="name3" value="value3" />
+                </meta_attributes>
+            </{self.cib_tag}>
+        """
+        xml_manip = XmlManipulation.from_file(empty_cib_rules)
+        xml_manip.append_to_first_tag_name("configuration", xml)
+        write_data_to_tmpfile(str(xml_manip), self.temp_cib)
+
+        self.assert_effect(
+            self.cli_command + "update name2=value2A name3=".split(),
+            dedent(
+                f"""\
+                <{self.cib_tag}>
+                    <meta_attributes id="X">
+                        <rule id="X-rule" boolean-op="and">
+                            <rsc_expression id="X-rule-rsc-Dummy" type="Dummy"/>
+                        </rule>
+                        <nvpair id="X-name1" name="name1" value="value1" />
+                        <nvpair id="X-name2" name="name2" value="value2A" />
+                    </meta_attributes>
+                </{self.cib_tag}>
+            """
+            ),
+            stderr_full=(
+                DEFAULTS_MAY_BE_OVERRIDDEN
+                + fixture_warning_unknown_meta_primitive(["name2"])
+            ),
+        )
 
 
 class OpDefaultsUpdate(
