@@ -1,6 +1,11 @@
 from textwrap import dedent
 
-from pcs_test.tier1.cib_resource.common import ResourceTest
+from pcs.common.str_tools import format_list, format_plural
+
+from pcs_test.tier1.cib_resource.common import (
+    ResourceTest,
+    fixture_use_meta_command_instead_warning,
+)
 from pcs_test.tools.bin_mock import get_mock_settings
 from pcs_test.tools.misc import ParametrizedTestMetaClass, write_data_to_tmpfile
 from pcs_test.tools.misc import get_test_resource as rc
@@ -9,6 +14,11 @@ ERRORS_HAVE_OCCURRED = (
     "Error: Errors have occurred, therefore pcs is unable to continue\n"
 )
 
+NOT_STOPPING_RESOURCE_NOT_LIVE_CLUSTER = (
+    "Warning: Resources are not going to be stopped before deletion because the"
+    " command does not run on a live cluster\n"
+)
+
 
 def fixture_nolive_add_report(node_name):
     return dedent(
@@ -20,13 +30,40 @@ def fixture_nolive_add_report(node_name):
     )
 
 
-def fixture_nolive_remove_report(host_list):
+def fixture_nolive_remove_remote_report(host_list):
+    return dedent(
+        """\
+        Warning: Not checking if {resources} {hosts} {are} stopped before deletion because the command does not run on a live cluster. Deleting unstopped resources may result in orphaned resources being present in the cluster.
+        Running action(s) 'pacemaker_remote disable', 'pacemaker_remote stop' on {hosts} was skipped because the command does not run on a live cluster (e.g. -f was used). Please, run the action(s) manually.
+        Removing 'pacemaker authkey' from {hosts} was skipped because the command does not run on a live cluster (e.g. -f was used). Please, remove the file(s) manually.
+        """
+    ).format(
+        resources=format_plural(host_list, "resource"),
+        hosts=", ".join("'{0}'".format(host) for host in host_list),
+        are=format_plural(host_list, "is"),
+    )
+
+
+def fixture_nolive_remove_guest_report(host_list):
     return dedent(
         """\
         Running action(s) 'pacemaker_remote disable', 'pacemaker_remote stop' on {hosts} was skipped because the command does not run on a live cluster (e.g. -f was used). Please, run the action(s) manually.
         Removing 'pacemaker authkey' from {hosts} was skipped because the command does not run on a live cluster (e.g. -f was used). Please, remove the file(s) manually.
         """
-    ).format(hosts=", ".join("'{0}'".format(host) for host in host_list))
+    ).format(
+        hosts=", ".join("'{0}'".format(host) for host in host_list),
+    )
+
+
+def fixture_nolive_node_remove(host_list):
+    return dedent(
+        """\
+        Warning: Skipping removal of {node} {node_list} from pacemaker because the command does not run on a live cluster
+        """.format(
+            node=format_plural(host_list, "node"),
+            node_list=format_list(host_list),
+        )
+    )
 
 
 class RemoteTest(ResourceTest):
@@ -396,7 +433,8 @@ class NodeAddGuest(RemoteTest):
         )
         self.pcs_runner.corosync_conf_opt = None
         self.assert_pcs_success(
-            "resource update G meta remote-node=node-name".split()
+            "resource update G meta remote-node=node-name".split(),
+            stderr_full=fixture_use_meta_command_instead_warning(),
         )
 
     def test_success_with_options(self):
@@ -514,8 +552,9 @@ class NodeDeleteRemoveRemote(RemoteTest):
     def _test_fail_when_node_does_not_exists(self):
         self.assert_pcs_fail(
             ["cluster", "node", self.command, "not-existent"],
-            "Error: remote node 'not-existent' does not appear to exist in"
-            " configuration\n",
+            NOT_STOPPING_RESOURCE_NOT_LIVE_CLUSTER
+            + "Error: remote node 'not-existent' does not appear to exist in"
+            " configuration\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def _test_success_remove_by_host(self):
@@ -524,8 +563,10 @@ class NodeDeleteRemoveRemote(RemoteTest):
             ["cluster", "node", self.command, "NODE-HOST"],
             "<resources/>",
             stderr_full=(
-                "Removing resource: 'NODE-NAME'\n"
-                + fixture_nolive_remove_report(["NODE-NAME"])
+                NOT_STOPPING_RESOURCE_NOT_LIVE_CLUSTER
+                + fixture_nolive_remove_remote_report(["NODE-NAME"])
+                + "Removing resource: 'NODE-NAME'\n"
+                + fixture_nolive_node_remove(["NODE-NAME"])
             ),
         )
 
@@ -535,8 +576,10 @@ class NodeDeleteRemoveRemote(RemoteTest):
             ["cluster", "node", self.command, "NODE-NAME"],
             "<resources/>",
             stderr_full=(
-                "Removing resource: 'NODE-NAME'\n"
-                + fixture_nolive_remove_report(["NODE-NAME"])
+                NOT_STOPPING_RESOURCE_NOT_LIVE_CLUSTER
+                + fixture_nolive_remove_remote_report(["NODE-NAME"])
+                + "Removing resource: 'NODE-NAME'\n"
+                + fixture_nolive_node_remove(["NODE-NAME"])
             ),
         )
 
@@ -544,7 +587,8 @@ class NodeDeleteRemoveRemote(RemoteTest):
         self.fixture_multiple_remote_nodes()
         self.assert_pcs_fail(
             ["cluster", "node", self.command, "HOST-A"],
-            "Error: more than one resource for 'HOST-A' found: "
+            NOT_STOPPING_RESOURCE_NOT_LIVE_CLUSTER
+            + "Error: more than one resource for 'HOST-A' found: "
             "'HOST-A', 'NODE-NAME', use --force to override\n"
             + ERRORS_HAVE_OCCURRED,
         )
@@ -555,10 +599,12 @@ class NodeDeleteRemoveRemote(RemoteTest):
             ["cluster", "node", self.command, "HOST-A", "--force"],
             "<resources/>",
             stderr_full=(
-                "Warning: more than one resource for 'HOST-A' found: "
+                NOT_STOPPING_RESOURCE_NOT_LIVE_CLUSTER
+                + "Warning: more than one resource for 'HOST-A' found: "
                 "'HOST-A', 'NODE-NAME'\n"
+                + fixture_nolive_remove_remote_report(["HOST-A", "NODE-NAME"])
                 + "Removing resources: 'HOST-A', 'NODE-NAME'\n"
-                + fixture_nolive_remove_report(["HOST-A", "NODE-NAME"])
+                + fixture_nolive_node_remove(["HOST-A", "NODE-NAME"])
             ),
         )
 
@@ -621,7 +667,7 @@ class NodeDeleteRemoveGuest(RemoteTest):
         self.assert_pcs_fail(
             ["cluster", "node", self.command, "not-existent", "--force"],
             "Error: guest node 'not-existent' does not appear to exist in"
-            " configuration\n",
+            " configuration\n" + ERRORS_HAVE_OCCURRED,
         )
 
     def assert_remove_by_identifier(self, identifier):
@@ -640,7 +686,8 @@ class NodeDeleteRemoveGuest(RemoteTest):
                     </operations>
                 </primitive>
             </resources>""",
-            stderr_full=fixture_nolive_remove_report(["NODE-NAME"]),
+            stderr_full=fixture_nolive_remove_guest_report(["NODE-NAME"])
+            + fixture_nolive_node_remove(["NODE-NAME"]),
         )
 
     def _test_success_remove_by_node_name(self):
