@@ -10,24 +10,19 @@ from pcs.common.pacemaker.nvset import (
     CibNvsetDto,
     ListCibNvsetDto,
 )
-from pcs.common.str_tools import (
-    format_list,
-    format_plural,
-)
+from pcs.common.str_tools import format_list, format_plural
 
 from pcs_test.tools.assertions import AssertPcsMixin
 from pcs_test.tools.cib import get_assert_pcs_effect_mixin
-from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
+    PacemakerFeatures,
     get_tmp_file,
     write_data_to_tmpfile,
     write_file_to_tmpfile,
 )
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.pcs_runner import PcsRunner
-from pcs_test.tools.xml import (
-    XmlManipulation,
-    etree_to_str,
-)
+from pcs_test.tools.xml import XmlManipulation, etree_to_str
 
 property_cib = rc("cib-property.xml")
 UNCHANGED_CRM_CONFIG = etree_to_str(
@@ -205,10 +200,33 @@ class TestPropertySet(PropertyMixin, TestCase):
         self.assert_resources_xml_in_cib(UNCHANGED_CRM_CONFIG)
 
     def test_set_stonith_watchdog_timeout_invalid_value(self):
+        deprecation = ""
+        if PacemakerFeatures.stonith_renamed_to_fencing():
+            deprecation = (
+                "Warning: cluster property option 'stonith-watchdog-timeout' "
+                "is deprecated and might be removed in a future release, "
+                "therefore it should not be used, use "
+                "'fencing-watchdog-timeout' instead\n"
+            )
+
         self.assert_pcs_fail(
             "property set stonith-watchdog-timeout=5x".split(),
             stderr_full=(
-                "Error: '5x' is not a valid stonith-watchdog-timeout value, use"
+                deprecation
+                + "Error: '5x' is not a valid stonith-watchdog-timeout value, "
+                "use time interval (e.g. 1, 2s, 3m, 4h, ...)\n"
+                "Error: Errors have occurred, therefore pcs is unable to "
+                "continue\n"
+            ),
+        )
+        self.assert_resources_xml_in_cib(UNCHANGED_CRM_CONFIG)
+
+    @PacemakerFeatures.skip_unless_stonith_renamed_to_fencing()
+    def test_set_fencing_watchdog_timeout_invalid_value(self):
+        self.assert_pcs_fail(
+            "property set fencing-watchdog-timeout=5x".split(),
+            stderr_full=(
+                "Error: '5x' is not a valid fencing-watchdog-timeout value, use"
                 " time interval (e.g. 1, 2s, 3m, 4h, ...)\n"
                 "Error: Errors have occurred, therefore pcs is unable to "
                 "continue\n"
@@ -216,6 +234,53 @@ class TestPropertySet(PropertyMixin, TestCase):
         )
         self.assert_resources_xml_in_cib(UNCHANGED_CRM_CONFIG)
 
+    def test_disable_fencing_warning(self):
+        deprecation = ""
+        if PacemakerFeatures.stonith_renamed_to_fencing():
+            deprecation = (
+                "Warning: cluster property option 'stonith-enabled' is "
+                "deprecated and might be removed in a future release, therefore "
+                "it should not be used, use 'fencing-enabled' instead\n"
+            )
+        self.assert_effect_single(
+            "property set stonith-enabled=false".split(),
+            """
+            <crm_config>
+                <cluster_property_set id="cib-bootstrap-options">
+                    <nvpair id="cib-bootstrap-options-have-watchdog"
+                        name="have-watchdog" value="false"
+                    />
+                    <nvpair id="cib-bootstrap-options-cluster-name"
+                        name="cluster-name" value="HACluster"
+                    />
+                    <nvpair id="cib-bootstrap-options-maintenance-mode"
+                        name="maintenance-mode" value="false"
+                    />
+                    <nvpair id="cib-bootstrap-options-placement-strategy"
+                        name="placement-strategy" value="minimal"
+                    />
+                    <nvpair id="cib-bootstrap-options-enable-acl"
+                        name="enable-acl" value="false"
+                    />
+                    <nvpair id="cib-bootstrap-options-stonith-enabled"
+                        name="stonith-enabled" value="false"
+                    />
+                </cluster_property_set>
+                <cluster_property_set id="second-set" score="10">
+                    <nvpair id="second-set-maintenance-mode"
+                        name="maintenance-mode" value="false"
+                    />
+                </cluster_property_set>
+            </crm_config>
+
+            """,
+            stderr_full=deprecation
+            + "Warning: Setting property stonith-enabled to false"
+            " leaves the cluster with no enabled means to fence nodes,"
+            " resulting in the cluster not being able to recover from"
+            " certain failure conditions\n",
+        )
+
 
 class TestPropertyUnset(PropertyMixin, TestCase):
     def test_success(self):
@@ -488,16 +553,13 @@ FIXTURE_BATCH_LIMIT_DESC = (
     "  Default: 0\n"
 )
 
-FIXTURE_STONITH_ENABLED_DESC = (
-    "stonith-enabled (advanced use only)\n"
-    "  Description: Whether nodes may be fenced as part of "
-    "recovery. If false, unresponsive nodes are immediately "
-    "assumed to be harmless, and resources that were active on "
-    "them may be recovered elsewhere. This can result in a "
-    '"split-brain" situation, potentially leading to data loss '
-    "and/or service unavailability.\n"
-    "  Type: boolean\n"
-    "  Default: true\n"
+FIXTURE_CLUSTER_NAME_DESC = (
+    "cluster-name\n"
+    "  Description: An arbitrary name for the cluster. This optional value is "
+    "mostly for users' convenience as desired in administration, but may also "
+    "be used in Pacemaker configuration rules via the #cluster-name node "
+    "attribute, and by higher-level tools and resource agents.\n"
+    "  Type: string\n"
 )
 
 
@@ -525,8 +587,8 @@ class TestPropertyDescribe(TestCase, AssertPcsMixin):
 
     def test_success_specific(self):
         self.assert_pcs_success(
-            "property describe stonith-enabled batch-limit".split(),
-            stdout_full=FIXTURE_BATCH_LIMIT_DESC + FIXTURE_STONITH_ENABLED_DESC,
+            "property describe cluster-name batch-limit".split(),
+            stdout_full=FIXTURE_BATCH_LIMIT_DESC + FIXTURE_CLUSTER_NAME_DESC,
         )
 
     def test_notexistent(self):
