@@ -63,8 +63,9 @@ def add_node_attr(auth_user, node, key, value)
   return retval
 end
 
-def add_meta_attr(auth_user, resource, key, value)
-  cmd = ["resource", "meta", resource, key.to_s + "=" + value.to_s]
+def add_meta_attr(auth_user, resource, key, value, is_stonith)
+  resource_or_stonith = if is_stonith then "stonith" else "resource" end
+  cmd = [resource_or_stonith, "meta", resource, key.to_s + "=" + value.to_s]
   flags = []
   if ["remote-node", "remote-addr"].include?(key.to_s)
     # --force is a workaround for missing guest node management in the web ui
@@ -960,178 +961,6 @@ def is_auth_against_nodes(auth_user, node_names, timeout=10)
   return online_nodes, offline_nodes, not_authorized_nodes
 end
 
-def pcs_auth_token(nodes)
-  # nodes is a hash of hashes:
-  # {
-  #   'node name' => {
-  #     'token' => auth token
-  #     'dest_list' => [ # currently only the first item is used
-  #       {'addr' => addr, 'port' => port} # how to connect to a node
-  #     ]
-  #   }
-  # }
-
-  new_hosts = []
-  nodes.each { |node_name, node_data|
-    new_hosts << PcsKnownHost.new(
-      node_name,
-      node_data['token'],
-      [node_data['dest_list'][0]]
-    )
-  }
-
-  # We want to avoid send updated known hosts to all cluster nodes therefore we
-  # are using 'nil' for cluster_name argument. Actually, automatic known hosts
-  # synchronization should be disabled in cluster when setting a custom token.
-  Cfgsync::save_sync_new_known_hosts(new_hosts, [], [], nil)
-end
-
-def pcs_auth(auth_user, nodes)
-  # nodes is a hash of hashes:
-  # {
-  #   'node name' => {
-  #     'username' => a username used for auth
-  #     'password' => a password used for auth
-  #     'dest_list' => [ # currently only the first item is used
-  #       {'addr' => addr, 'port' => port} # how to connect to a node
-  #     ]
-  #   }
-  # }
-
-  # authorize against the nodes
-  auth_responses = {}
-  threads = []
-  nodes.each { |node_name, node_data|
-    threads << Thread.new(Thread.current[:pcsd_logger_container]) { |logger|
-      Thread.current[:pcsd_logger_container] = logger
-      begin
-        addr = node_data.fetch('dest_list').fetch(0).fetch('addr')
-        port = node_data.fetch('dest_list').fetch(0).fetch('port')
-        request_data = {
-          :username => node_data.fetch('username'),
-          :password => node_data.fetch('password'),
-        }
-        code, response = send_request(
-          auth_user, addr, port, 'auth', true, request_data, true
-        )
-        if 200 == code
-          token = response.strip
-          if '' == token
-            auth_responses[node_name] = {'status' => 'bad_password'}
-          else
-            auth_responses[node_name] = {'status' => 'ok', 'token' => token}
-          end
-        else
-          auth_responses[node_name] = {'status' => 'noresponse'}
-        end
-      rescue => e
-        auth_responses[node_name] = {'status' => 'error', 'error' => e}
-      end
-    }
-  }
-  threads.each { |t| t.join }
-
-  # get the tokens form the response
-  new_hosts = []
-  auth_responses.each { |node_name, response|
-    if 'ok' == response['status']
-      new_hosts << PcsKnownHost.new(
-        node_name,
-        response['token'],
-        [nodes[node_name]['dest_list'][0]]
-      )
-    end
-  }
-
-  # sync known hosts within the local cluster
-  sync_successful = true
-  sync_failed_nodes = []
-  sync_responses = {}
-  if new_hosts.empty?
-    return auth_responses, sync_successful, sync_failed_nodes, sync_responses
-  end
-  # Only tokens used in pcsd-to-pcsd communication can and need to be synced.
-  # Those are accessible only when running under root account.
-  if Process.uid != 0
-    # Other tokens just need to be stored localy for a user.
-    sync_successful, sync_responses = Cfgsync::save_sync_new_known_hosts(
-      new_hosts, [], [], nil
-    )
-    return auth_responses, sync_successful, sync_failed_nodes, sync_responses
-  end
-  cluster_nodes = get_corosync_nodes_names()
-  sync_successful, sync_responses = Cfgsync::save_sync_new_known_hosts(
-    new_hosts, [], cluster_nodes, $cluster_name
-  )
-  # sync_notauthorized_nodes is not used because clients extract that info from
-  # auth_responses themselves
-  sync_notauthorized_nodes, sync_failed_nodes = (
-    Cfgsync::get_failed_nodes_from_sync_responses(sync_responses)
-  )
-  return auth_responses, sync_successful, sync_failed_nodes, sync_responses
-end
-
-def pcs_deauth(auth_user, host_names)
-  # sync known hosts within the local cluster
-  sync_successful = true
-  sync_failed_nodes = []
-  sync_responses = {}
-  hosts_not_found = []
-
-  if host_names.empty?
-    return sync_successful, sync_failed_nodes, sync_responses, hosts_not_found
-  end
-  known_hosts_names = get_known_hosts().keys()
-  host_names.each { |name_to_remove|
-    if not known_hosts_names.include?(name_to_remove)
-      hosts_not_found << name_to_remove
-    end
-  }
-  if hosts_not_found.length > 0
-    return sync_successful, sync_failed_nodes, sync_responses, hosts_not_found
-  end
-
-  # Only tokens used in pcsd-to-pcsd communication can and need to be synced.
-  # Those are accessible only when running under root account.
-  if Process.uid != 0
-    # Other tokens just need to be stored localy for a user.
-    sync_successful, sync_responses = Cfgsync::save_sync_new_known_hosts(
-      [], host_names, [], nil
-    )
-    return sync_successful, sync_failed_nodes, sync_responses, hosts_not_found
-  end
-  cluster_nodes = get_corosync_nodes_names()
-  sync_successful, sync_responses = Cfgsync::save_sync_new_known_hosts(
-    [], host_names, cluster_nodes, $cluster_name
-  )
-  sync_responses.each { |node, response|
-    if response['status'] != 'ok'
-      sync_failed_nodes << node
-    else
-      node_result = response['result'][Cfgsync::PcsdKnownHosts.name]
-      if not ['accepted', 'rejected'].include?(node_result)
-        sync_failed_nodes << node
-      end
-    end
-  }
-  return sync_successful, sync_failed_nodes, sync_responses, hosts_not_found
-end
-
-def send_local_configs_to_nodes(
-  auth_user, nodes, force=false, clear_local_permissions=false
-)
-  configs = Cfgsync::get_configs_local(true)
-  if clear_local_permissions
-    pcs_config = PCSConfig.new(configs[Cfgsync::PcsdSettings.name].text())
-    pcs_config.permissions_local = Permissions::PermissionsSet.new([])
-    configs[Cfgsync::PcsdSettings.name].text = pcs_config.text()
-  end
-  publisher = Cfgsync::ConfigPublisher.new(
-    auth_user, configs.values(), nodes, $cluster_name
-  )
-  return publisher.send(force)
-end
-
 def get_uid(username)
   return Etc.getpwnam(username).uid
 end
@@ -1353,8 +1182,14 @@ def cluster_status_from_nodes(auth_user, cluster_nodes, cluster_name)
       }
     end
 
-    if status[:cluster_settings]['stonith-enabled'.to_sym] and
-        not is_cib_true(status[:cluster_settings]['stonith-enabled'.to_sym])
+    stonith_disabled = (
+      status[:cluster_settings]['stonith-enabled'.to_sym] and
+      not is_cib_true(status[:cluster_settings]['stonith-enabled'.to_sym])
+    ) || (
+      status[:cluster_settings]['fencing-enabled'.to_sym] and
+      not is_cib_true(status[:cluster_settings]['fencing-enabled'.to_sym])
+    )
+    if stonith_disabled
       status[:warning_list] << {
         :message => 'Stonith is not enabled',
       }
